<?php

class CourseCatalogSettings {
    /**
     * Holds the values to be used in the fields callbacks
     */
    protected $options;
    protected $option_name = 'ccs_option_name';
    protected $option_page_id = 'ccs-plugin-settings';

    // Default values
    protected $option_data = array(
        'ccs_url' => 'http://localhost/usimccs'
    );

    /**
     * Start up
     */
    public function __construct()
    {
        add_action('admin_init', array($this, 'page_init'));
        add_action('admin_menu', array($this, 'add_plugin_page'));

        // Listen for the activate event
        register_activation_hook(CCS_PLUGIN_FILE, array($this, 'activate'));
    }

    /**
     * Add options page
     */
    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            'Course Catalog System Plugin Settings',
            'Course Catalog System',
            'manage_options',
            $this->option_page_id,
            array($this, 'create_admin_page')
        );
    }

    /**
     * Options page callback
     */
    public function create_admin_page()
    {
        // Set class property
        $this->options = get_option($this->option_name);
        ?>
        <div class="wrap">
            <h2>Course Catalog System</h2>
            <form method="post" action="options.php">
            <?php
                // This prints out all hidden setting fields
                settings_fields('ccs_option_group');
                do_settings_sections($this->option_page_id);
                submit_button();
                print_r($this->options, true);
            ?>
            </form>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {
        register_setting(
            'ccs_option_group', // Option group
            $this->option_name, // Option name
            array($this, 'sanitize') // Sanitize
        );

        add_settings_section(
            'setting_section_id',				// ID
            'Settings',							// Title
            array($this, 'print_section_info'),	// Callback
            $this->option_page_id					// Page
        );

        add_settings_field(
            'ccs_url',								// ID
            'Course Catalog System URL',			// Title
            array($this, 'ccs_url_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );
    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize($input)
    {
        $new_input = array();

        if (isset($input['ccs_url']))
            $new_input['ccs_url'] = sanitize_text_field($input['ccs_url']);

        return $new_input;
    }

    /**
     * Print the Section text
     */
    public function print_section_info()
    {
        //print 'Enter your settings below:';
    }

    /**
     * Get the settings option array and print one of its values
     */
    public function ccs_url_callback()
    {
        printf(
            '<input type="text" id="ccs_url" name="%s[ccs_url]" value="%s" size="30" />',
            $this->option_name,
            isset($this->options['ccs_url']) ? esc_attr($this->options['ccs_url']) : $this->option_data['ccs_url']
        );
    }
}

if (is_admin())
{
    $ccs_settings = new CourseCatalogSettings();
}
