<?php
/*
Plugin Name: Course Catalog System
Plugin URI: http://www.nizma.com.my/
Description: Fetches the content of Course Catalog System to display inside the current post or page.
Author: Hairulnizam Zulkefli
Author URI: http://www.nizma.com.my/
Tags: wordpress, catalog
Version: 1.1.1
*/

define('CCS_OPTION_NAME', 'ccs_option_name');
define('CCS_PLUGIN_FILE', __FILE__);					// This file name
define('CCS_PLUGIN_PATH', plugin_dir_path(__FILE__));	// Path to this plugin, with trailing '/'
define('CCS_SEARCH_FORM', plugin_dir_path(__FILE__) . 'search-form.php');
define('CCS_SEARCH_RESULT', plugin_dir_path(__FILE__) . 'search-result.php');
define('CCS_SEARCH_NO_RESULT', plugin_dir_path(__FILE__) . 'search-no-result.php');
define('CCS_SEARCH_BOX', plugin_dir_path(__FILE__) . 'search-box.php');
define('CCS_SEARCH_BOX_DUMMY', plugin_dir_path(__FILE__) . 'search-box-dummy.php');
define('CCS_SIDEBAR_SEARCH', plugin_dir_path(__FILE__) . 'sidebar-search-result.php');

// Default values if not set
define('CCS_TAG_BGCOLOR', '#a0ce4e');
define('CCS_TAG_COLOR', '#ffffff');
define('CCS_TAG_NEW_BGCOLOR', '#f89406');
define('CCS_TAG_NEW_COLOR', '#ffffff');

require_once CCS_PLUGIN_PATH . 'ccs-options.php';

/**
 * Function using all available methods to open remote site and return content
 * - file_get_contents()
 * - cURL
 */
function ccs_get_content_curl($url)
{
    $response = array();

    $response['url'] = $url;

//    if (function_exists('file_get_contents'))
//    {
//        $html = @file_get_contents($url);
//
//        if ($html !== FALSE)
//        {
//            $response['http_code'] = 200;
//            $response['method'] = 'file_get_contents';
//            $response['html'] = $html;
//
//            return $response;
//        }
//    }
//
    if (is_callable('curl_init'))
    {
        $referer = get_bloginfo('url');
        $timeout = 30;

        $curl = curl_init();

        if (strstr($referer, "://"))
        {
            curl_setopt ($curl, CURLOPT_REFERER, $referer);
        }

        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_HTTPGET, TRUE);			// reset the HTTP request method to GET
        curl_setopt($curl, CURLOPT_TIMEOUT, $timeout);		// maximum number of seconds to allow cURL functions to execute
        curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, 30);		// number of seconds to wait while trying to connect
        curl_setopt($curl, CURLOPT_USERAGENT, sprintf("Mozilla/%d.0", rand(4, 5)));
        curl_setopt($curl, CURLOPT_HEADER, FALSE);			// exclude the header in the output
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, TRUE);	// return the transfer as a string of the return value instead of output
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($curl, CURLOPT_MAXREDIRS, 10);

        if (substr($url, 0, 5) == 'https')
        {
            curl_setopt($curl, CURLOPT_SSLVERSION, 3);			// Supports only SSL version 3
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, TRUE);	// verify the peer's certificate
        }
        else
        {
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);
        }

        $html = curl_exec($curl);
        $http_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);

        if ( ! curl_errno($curl))
        {
            $response['http_code'] = 200;
            $response['method'] = 'curl';
            $response['html'] = $html;

            curl_close($curl);

            return $response;
        }
        else
        {
            $response['http_code'] = curl_errno($curl);
            $response['method'] = 'curl';
            $response['html'] = curl_error($curl);

            curl_close($curl);

            return $response;
        }
    }
    else
    {
        $response['http_code'] = 403;
        $response['method'] = '';
        $response['html'] = 'cURL is not available';

        return $response;
    }
}

/**
 * Function using cURL and post data to remote site and return content
 */
function ccs_post_content_curl($url, $data)
{
    $response = array();

    $response['url'] = $url;

    if (is_callable('curl_init'))
    {
        $referer = get_bloginfo('url');
        $timeout = 30;

        $curl = curl_init();

        if (strstr($referer, "://"))
        {
            curl_setopt ($curl, CURLOPT_REFERER, $referer);
        }

        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $data);
        curl_setopt($curl, CURLOPT_TIMEOUT, $timeout);		// maximum number of seconds to allow cURL functions to execute
        curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, 7);		// number of seconds to wait while trying to connect
        curl_setopt($curl, CURLOPT_USERAGENT, sprintf("Mozilla/%d.0", rand(4, 5)));
        curl_setopt($curl, CURLOPT_HEADER, FALSE);			// exclude the header in the output
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, TRUE);	// return the transfer as a string of the return value instead of output
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($curl, CURLOPT_MAXREDIRS, 10);

        if (substr($url, 0, 5) == 'https')
        {
            curl_setopt($curl, CURLOPT_SSLVERSION, 3);			// Supports only SSL version 3
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, TRUE);	// verify the peer's certificate
        }
        else
        {
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);
        }

        $html = curl_exec($curl);
        $http_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);

        if ( ! curl_errno($curl))
        {
            $response['http_code'] = 200;
            $response['method'] = 'curl';
            $response['html'] = $html;

            curl_close($curl);

            return $response;
        }
        else
        {
            $response['http_code'] = curl_errno($curl);
            $response['method'] = 'curl';
            $response['html'] = curl_error($curl);

            curl_close($curl);

            return $response;
        }
    }
    else
    {
        $response['http_code'] = 403;
        $response['method'] = '';
        $response['html'] = 'cURL is not available';

        return $response;
    }
}

/**
 * Function calling above function (ccs_get_content_curl) to open remote site and return content only if successful,
 * upon failure return nothing ('')
 *
 * -- Not used
 */
function ccs_get_content($atts)
{
    $response = ccs_get_content_curl($atts);

    if ($response['http_code'] == 200)
    {
        return $response['html'];
    }
    else
    {
        return '';
    }
}
add_shortcode('ccs_get_content', 'ccs_get_content');

/**
 * Function to open url and return JSON data in json_decoded format.
 * This is local function and not to be used as plugin function
 */
function get_json_content($url = '')
{
    if ( ! empty($url))
    {
        $options = get_option(CCS_OPTION_NAME);
        $ccs_url = $options['ccs_url'];

        $remote_url = $ccs_url . $url;
        $response = ccs_get_content_curl($remote_url);

        if (isset($response['html']))
        {
            $json_data = $response['html'];
            return json_decode($json_data);
        }
    }

    return array();
}

/**
 * List of faculties - with a building image, and 4 buttons:
 * - Academic Programme - List of programmes of a faculty
 * - Expertise
 * - Download Brochure
 * - Visit Website
 */
function ccs_render_faculty_list($atts)
{
    // /api/wordpress/faculties

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_faculty_program_page = $options['ccs_faculty_program_page'];
    $ccs_faculty_id_param = $options['ccs_faculty_id_param'];
    $ccs_header_colors = $options['ccs_header_colors'];
    $ccs_header_colors = explode(',', $ccs_header_colors);
    if (count($ccs_header_colors) == 0)
    {
        $ccs_header_colors = array('#1f86c1', '#dd3333');
    }

    $remote_url = $ccs_url . '/api/wordpress/faculties/' . $lang;
    $response = ccs_get_content_curl($remote_url);

    $json_data = $response['html'];
    $faculties = json_decode($json_data);

    if (count($faculties) > 0)
    {
        $output = '';
        $faculty_count = 0;

        foreach ($faculties as $faculty)
        {
            $faculty_count++;
            $color_index = $ccs_header_colors[($faculty_count % count($ccs_header_colors))];

            $output .= '<div class="col-md-12 aligncenter faculty-header" style="background-color:' . $color_index . ';">';
            $output .= '<h2 style="text-transform: uppercase;">';
            $output .= $faculty->faculty_name;
            if ( ! empty($faculty->faculty_code))
            {
                $output .= ' (' . $faculty->faculty_code . ')';
            }
            $output .= '</h2>';
            $output .= '</div>';

            $output .= '<div class="col-md-12">&nbsp;</div>';

            $output .= '<div class="col-md-8" style="text-align: right;">';
                $output .= '<img src="' . plugins_url('images/img1.jpg', __FILE__) . '" alt="">';
                $output .= '<div class="col-xs-12">&nbsp;</div>';
            $output .= '</div>';

            $output .= '<div class="col-md-4 faculty-buttons">';
                $output .= '<div class="col-xs-6" style="min-height: 130px;">';
                    $output .= '<a href="' . get_site_url() . $ccs_faculty_program_page . '?' . $ccs_faculty_id_param . '=' . $faculty->faculty_id . '">';
                    $output .= '<i class="fa fa-graduation-cap"></i>' . '<br>';
                    $output .= __('ACADEMIC PROGRAMME', 'course-catalog-system');
                    $output .= '</a>';
                $output .= '</div>';

                $output .= '<div class="col-xs-6" style="min-height: 130px;">';
                    $output .= '<a href="">';
                    $output .= '<i class="fa fa-lightbulb-o"></i>' . '<br>';
                    $output .= __('EXPERTISE', 'course-catalog-system');
                    $output .= '</a>';
                $output .= '</div>';

                $output .= '<br class="clearfix">';

                $output .= '<div class="col-xs-6" style="min-height: 130px;">';
                    $output .= '<a href="">';
                    $output .= '<i class="fa fa-download"></i>' . '<br>';
                    $output .= __('DOWNLOAD BROCHURE', 'course-catalog-system');
                    $output .= '</a>';
                $output .= '</div>';

                $output .= '<div class="col-xs-6" style="min-height: 130px;">';
                    $output .= '<a href="">';
                    $output .= '<i class="fa fa-chain"></i>' . '<br>';
                    $output .= __('VISIT WEBSITE', 'course-catalog-system');
                    $output .= '</a>';
                $output .= '</div>';
            $output .= '</div>';
        }

        return $output . eol();
    }
    else
    {
        return '';
    }
}
add_shortcode('ccs_render_faculty_list', 'ccs_render_faculty_list');

/**
 * Function to show list of programmes (by level of study - optional)
 */
function ccs_render_program_list($atts = null)
{
    // /api/wordpress/programs/{studylevel}/{lang}

    if ( ! empty($atts))
    {
        $attributes = shortcode_atts(array(
            'studylevel_id' => ''			// Default to Undergraduate Studies
        ), $atts);
    }
    else
    {
        $attributes['studylevel_id'] = '';
    }

    $studylevel_id = $attributes['studylevel_id'];

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_program_details_page = $options['ccs_program_details_page'];
    $ccs_tag_new_background_color = $options['ccs_tag_new_background_color'];
    if (empty($ccs_tag_new_background_color)) $ccs_tag_new_background_color = CCS_TAG_NEW_BGCOLOR;
    $ccs_tag_new_color = $options['ccs_tag_new_color'];
    if (empty($ccs_tag_new_color)) $ccs_tag_new_color = CCS_TAG_NEW_COLOR;

    $remote_url = $ccs_url . '/api/wordpress/programs_count/' . $studylevel_id . '/' . $lang;
    $response = ccs_get_content_curl($remote_url);

    $json_data = $response['html'];
    $faculties = json_decode($json_data);		// Program count

    $output = '';

    if (count($faculties) > 0)
    {
        $remote_url = $ccs_url . '/api/wordpress/programs/' . $studylevel_id . '/' . $lang;

        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $programs = json_decode($json_data);

        if (count($programs) > 0)
        {
            if ($studylevel_id == '11')
            {
                /*
                //   '10' - By Research
                // '1000' - By Coursework
                // '1010' - Mixed Mode
                $study_modes = array('0', '10', '1000', '1010');
                $study_mode_title = array(
                    '0'    => '',
                    '10'   => __('By Research', 'course-catalog-system'),
                    '1000' => __('By Coursework', 'course-catalog-system'),
                    '1010' => __('By Mixed Mode', 'course-catalog-system')
                );
                $study_mode_count = array();

                foreach ($study_modes as $study_mode)
                {
                    $scnt = 0;
                    foreach ($programs as $program)
                    {
                        if ($program->program_research_coursework == $study_mode)
                        {
                            $scnt++;
                        }
                    }
                    $study_mode_count[$study_mode] = $scnt;
                }
                */

                $remote_url = $ccs_url . '/api/wordpress/program_options/' . $lang;
                $response = ccs_get_content_curl($remote_url);

                $json_data = $response['html'];
                $study_modes_json = json_decode($json_data);

                $study_modes = array();
                $study_mode_title = array();

                foreach ($study_modes_json as $study_mode_json)
                {
                    $study_modes[] = $study_mode_json->program_option_id;
                    $study_mode_title[$study_mode_json->program_option_id] = $study_mode_json->program_option_name;
                }

                $study_mode_count = array();

                foreach ($study_modes as $study_mode)
                {
                    $scnt = 0;
                    foreach ($programs as $program)
                    {
                        //if ($program->program_research_coursework == $study_mode)
                        if ($program->program_option_id	 == $study_mode)
                        {
                            $scnt++;
                        }
                    }
                    $study_mode_count[$study_mode] = $scnt;
                }

                $count_local = 0;

                $output .= '<div class="table-1">';
                $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                $output .= '<thead>';
                $output .= '<tr>';
                $output .= '<th style="width: 5%;">&nbsp;</th>';
                $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                $output .= '<th>' . __('Programme Option', 'course-catalog-system') . '</th>';
                $output .= '<th>' . __('Faculty', 'course-catalog-system') . '</th>';
                $output .= '</tr>';
                $output .= '</thead>' . "\n";
                $output .= '<tbody>' . "\n";

                $program_count = 0;
                $current_study_mode = '';

                foreach ($study_modes as $study_mode)
                {
                    //$program_count = 0;

                    if ($study_mode_count[$study_mode] > 0)
                    {
                        $output .= "\n";
                        if ($study_mode_title[$study_mode] != '')
                        {
                            //$output .= '<h3>' . $study_mode_title[$study_mode] . '</h3>';
                        }
//                        $output .= '<div class="table-1">';
//                        $output .= '<table class="ccs-program-table" width="100%">' . "\n";
//                        $output .= '<thead>';
//                        $output .= '<tr>';
//                        $output .= '<th style="width: 5%;">&nbsp;</th>';
//                        $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
//                        $output .= '<th style="width: 45%;">' . __('Faculty', 'course-catalog-system') . '</th>';
//                        $output .= '</tr>';
//                        $output .= '</thead>' . "\n";
//                        $output .= '<tbody>' . "\n";

                        $faculty_row = 0;

                        foreach ($faculties as $faculty)
                        {
                            $row = 1;

                            foreach ($programs as $program)
                            {

//                                if ($program->faculty_id == $faculty->faculty_id &&
//                                    $program->program_research_coursework == $faculty->program_research_coursework &&
//                                    $program->program_research_coursework == $study_mode)
//                                {
                                if ($program->faculty_id == $faculty->faculty_id &&
                                    $program->program_option_id == $faculty->program_option_id &&
                                    $program->program_option_id == $study_mode)
                                {
                                    $program_count++;

                                    $output .= '<tr>';
                                    $output .= '<td style="text-align: center;">' . $program_count . '</td>';

                                    $output .= '<td>';

                                    if ($program->program_scope == 'L')
                                    {
                                        $output .= '<span style="color:red;">*</span>&nbsp;';
                                        $count_local++;
                                    }

                                    if ( ! empty($program->program_code))
                                    {
                                        $output .= $program->program_code . ': ';
                                    }

                                    $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                                    $output .= $program->program_name;
                                    $output .= '</a>';

                                    if ($program->program_is_new == '1')
                                    {
                                        $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                                        $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                                        $tag .= __('New');
                                        $tag .= '</span>';
                                        $tag .= '[/highlight]';

                                        $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                                    }

                                    $output .= '</td>';

                                    if ($current_study_mode != $study_mode)
                                    {
                                        $output .= '<td rowspan="' . $study_mode_count[$study_mode] . '">' . $study_mode_title[$study_mode] . '</td>';
                                        $current_study_mode = $study_mode;
                                    }

                                    // Using rowspan
                                    if ($row == 1)
                                    {
                                        if ($faculty_row == 0 OR $faculty_row % 2 == 0)
                                        {
                                            $output .= '<td rowspan="' . $faculty->program_count . '" style="background-color: #ffffff;">';	// rowspan required for styling (even for 1 row)
                                        }
                                        else
                                        {
                                            $output .= '<td rowspan="' . $faculty->program_count . '" style="background-color: #f6f6f6;">';	// rowspan required for styling (even for 1 row)
                                        }
                                        $output .= ( ! empty($faculty->faculty_name) ? $faculty->faculty_name : '&nbsp;');
                                        $output .= '</td>';
                                    }

                                    $output .= '</tr>' . "\n";
                                    $row++;
                                }
                            }
                            //$output .= '</tr>' . "\n";

                            $faculty_row++;
                        }

//                        $output .= '</tbody>' . "\n";
//                        $output .= '</table>' . "\n";
//                        $output .= '</div>' . "\n";
//                        $output .= '<br>';
                    }
                }

                $output .= '</tbody>' . "\n";
                $output .= '</table>' . "\n";
                $output .= '</div>' . "\n";
                $output .= '<br>';

                if ($count_local > 0)
                {
                    $output .= '<div class="ccs-text">';
                    $output .= __('Programme marked (', 'course-catalog-system');
                    $output .= '<span style="color:red;">*</span>';
                    $output .= __(') are not available for international students', 'course-catalog-system');
                    $output .= '</div>';
                }

                return $output . eol();
            }
            else if ($studylevel_id == '12')
            {
                // Undergraduate Studies

                $output  = "\n";
                $output .= '<div class="table-1">';
                $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                $output .= '<thead>';
                $output .= '<tr>';
                $output .= '<th style="width: 5%;">&nbsp;</th>';
                $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                $output .= '<th style="width: 45%;">' . __('Faculty', 'course-catalog-system') . '</th>';
                $output .= '</tr>';
                $output .= '</thead>' . "\n";
                $output .= '<tbody>' . "\n";

                $count_local = 0;
                $program_count = 0;

                foreach ($faculties as $faculty)
                {
                    if ( ! empty($faculty->faculty_name))
                    {
                        $row = 1;

                        foreach ($programs as $program)
                        {
                            if ($program->faculty_id == $faculty->faculty_id)
                            {
                                $program_count++;

                                $output .= '<tr>';
                                $output .= '<td style="text-align: center;">' . $program_count . '</td>';

                                $output .= '<td>';

                                if ($program->program_scope == 'L')
                                {
                                    $output .= '<span style="color:red;">*</span>&nbsp;';
                                    $count_local++;
                                }
                                if ( ! empty($program->program_code))
                                {
                                    $output .= $program->program_code . ': ';
                                }

                                $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                                $output .= $program->program_name;
                                $output .= '</a>';

                                if ($program->program_is_new == '1')
                                {
                                    $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                                    $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                                    $tag .= __('New');
                                    $tag .= '</span>';
                                    $tag .= '[/highlight]';

                                    $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                                }

                                $output .= '</td>';

                                if ($row == 1)
                                {
                                    $output .= '<td rowspan="' . $faculty->program_count . '" style="background-color: #ffffff;">';		// rowspan required for styling (even for 1 row)
                                    $output .= $faculty->faculty_name;
                                    $output .= '</td>';
                                }

                                $output .= '</tr>' . "\n";
                                $row++;
                            }
                        }
                        $output .= '</tr>' . "\n";
                    }
                }

                $output .= '</tbody>' . "\n";
                $output .= '</table>' . "\n";
                $output .= '</div>' . "\n";
                $output .= '<br>';

                $output .= '<div class="ccs-text">';
                $output .= __('Programme marked (', 'course-catalog-system');
                $output .= '<span style="color:red;">*</span>';
                $output .= __(') are not available for international students', 'course-catalog-system');
                $output .= '</div>';

                return $output . eol();
            }
            else
            {
                // Advanced Diploma & Tamhidi only

                $output  = "\n";
                $output .= '<div class="table-1">';
                $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                $output .= '<thead>';
                $output .= '<tr>';
                $output .= '<th style="width: 5%;">&nbsp;</th>';
                $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                $output .= '</tr>';
                $output .= '</thead>' . "\n";
                $output .= '<tbody>' . "\n";

                $count_local = 0;
                $program_count = 0;

                foreach ($faculties as $faculty)
                {
                    $row = 1;

                    foreach ($programs as $program)
                    {
                        if ($program->faculty_id == $faculty->faculty_id)
                        {
                            $program_count++;

                            $output .= '<tr>';
                            $output .= '<td style="text-align: center;">' . $program_count . '</td>';

                            $output .= '<td>';
                            if ($program->program_scope == 'L')
                            {
                                $output .= '<span style="color:red;">*</span>&nbsp;';
                                $count_local++;
                            }
                            if ( ! empty($program->program_code))
                            {
                                $output .= $program->program_code . ': ';
                            }

                            $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                            $output .= $program->program_name;
                            $output .= '</a>';

                            if ($program->program_is_new == '1')
                            {
                                $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                                $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                                $tag .= __('New');
                                $tag .= '</span>';
                                $tag .= '[/highlight]';

                                $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                            }

                            $output .= '</td>';
                            $output .= '</tr>' . "\n";
                            $row++;
                        }
                    }
                }

                $output .= '</tbody>' . "\n";
                $output .= '</table>' . "\n";
                $output .= '</div>';
                $output .= '<br>';

                $output .= '<div class="ccs-text">';
                $output .= __('Programme marked (', 'course-catalog-system');
                $output .= '<span style="color:red;">*</span>';
                $output .= __(') are not available for international students', 'course-catalog-system');
                $output .= '</div>';

                return $output . eol();
            }
        }
        else
        {
            return '';
        }
    }
    else
    {
        return __('No result', 'course-catalog-system') . eol();
    }
}
add_shortcode('ccs_render_program_list', 'ccs_render_program_list');

/**
 * List programmes under particular faculty, grouped by level of studies
 */
function ccs_render_faculty_program_list($atts = null)
{
    // /api/wordpress/faculty_programs/{faculty}/{lang}

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_faculty_id_param = $options['ccs_faculty_id_param'];
    $ccs_program_details_page = $options['ccs_program_details_page'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_program_search_page = $options['ccs_program_search_page'];
    $ccs_tag_new_background_color = $options['ccs_tag_new_background_color'];
    if (empty($ccs_tag_new_background_color)) $ccs_tag_new_background_color = CCS_TAG_NEW_BGCOLOR;
    $ccs_tag_new_color = $options['ccs_tag_new_color'];
    if (empty($ccs_tag_new_color)) $ccs_tag_new_color = CCS_TAG_NEW_COLOR;

    $fid = isset( $_GET[$ccs_faculty_id_param] ) ? ($_GET[$ccs_faculty_id_param] != '' ? $_GET[$ccs_faculty_id_param] : 'all') : 'all';

    $faculty_name = '';
    $output = '';

    if ($fid == 'all')
    {
        $remote_url = $ccs_url . '/api/wordpress/order_studylevels/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $studylevels = json_decode($json_data);

        $count_local = 0;

        $output = '[fusion_tabs design="classic" layout="horizontal" justified="yes" class="ccs-tabs"]';

        foreach ($studylevels as $studylevel)
        {
            $remote_url = $ccs_url . '/api/wordpress/programs_count/' . $studylevel->studylevel_id . '/' . $lang;
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $faculties = json_decode($json_data);		// Program count

            if (count($faculties) > 0)
            {
                //$output .= '<h2>' . $studylevel->studylevel_name . '</h2>';

                $output .= '[fusion_tab title="' . $studylevel->studylevel_name . '"]';

                $remote_url = $ccs_url . '/api/wordpress/programs/' . $studylevel->studylevel_id . '/' . $lang;

                $response = ccs_get_content_curl($remote_url);

                $json_data = $response['html'];
                $programs = json_decode($json_data);

                if (count($programs) > 0)
                {
                    if ($studylevel->studylevel_id == '11')
                    {
                        /*
                        //   '10' - By Research
                        // '1000' - By Coursework
                        // '1010' - Mixed Mode
                        $study_modes = array('0', '10', '1000', '1010');
                        $study_mode_title = array(
                            '0'    => '',
                            '10'   => __('By Research', 'course-catalog-system'),
                            '1000' => __('By Coursework', 'course-catalog-system'),
                            '1010' => __('By Mixed Mode', 'course-catalog-system')
                        );
                        $study_mode_count = array();
                        */

                        $remote_url = $ccs_url . '/api/wordpress/program_options/' . $lang;
                        $response = ccs_get_content_curl($remote_url);

                        $json_data = $response['html'];
                        $study_modes_json = json_decode($json_data);

                        $study_modes = array();
                        $study_mode_title = array();

                        foreach ($study_modes_json as $study_mode_json)
                        {
                            $study_modes[] = $study_mode_json->program_option_id;
                            $study_mode_title[$study_mode_json->program_option_id] = $study_mode_json->program_option_name;
                        }

                        $study_mode_count = array();

                        foreach ($study_modes as $study_mode)
                        {
                            $scnt = 0;
                            foreach ($programs as $program)
                            {
                                //if ($program->program_research_coursework == $study_mode)
                                if ($program->program_option_id == $study_mode)
                                {
                                    $scnt++;
                                }
                            }
                            $study_mode_count[$study_mode] = $scnt;
                        }

                        $grad_types = array('phd', 'master');
                        $phd_master_count = array();

                        $phd_count = 0;
                        $master_count = 0;

                        foreach ($programs as $program)
                        {
                            if (strtolower(substr($program->program_name, 0, strlen('Doctor of '))) == 'doctor of ')
                            {
                                $phd_count++;
                            }
                            if (strtolower(substr($program->program_name, 0, strlen('Master of '))) == 'master of ')
                            {
                                $master_count++;
                            }
                        }
                        $phd_master_count['phd'] = $phd_count;
                        $phd_master_count['master'] = $master_count;

                        foreach ($grad_types as $grad_type)
                        {
                            if ($phd_master_count[$grad_type] > 0)
                            {
                                if ($grad_type == 'phd')
                                {
                                    $output .= '<h2>' . __('Ph.D Programmes') . '</h2>';
                                }
                                else if ($grad_type == 'master')
                                {
                                    $output .= '<h2>' . __('Master Programmes') . '</h2>';
                                }

                                $output .= "\n";
                                $output .= '<div class="table-1">';
                                $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                                $output .= '<thead>';
                                $output .= '<tr>';
                                $output .= '<th style="width: 5%;">&nbsp;</th>';
                                $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                                $output .= '<th>' . __('Program Option', 'course-catalog-system') . '</th>';
                                $output .= '<th>' . __('Faculty', 'course-catalog-system') . '</th>';
                                $output .= '</tr>';
                                $output .= '</thead>' . "\n";
                                $output .= '<tbody>' . "\n";

                                $program_count = 0;
                                $study_mode_row = 0;
                                $faculty_row = 0;

                                foreach ($study_modes as $study_mode)
                                {
                                    $srow = 1;

                                    if ($study_mode_count[$study_mode] > 0)
                                    {
                                        foreach ($faculties as $faculty)
                                        {
                                            $row = 1;

                                            foreach ($programs as $program)
                                            {
                                                if (($grad_type == 'phd' && strtolower(substr($program->program_name, 0, strlen('Doctor of '))) == 'doctor of ') OR
                                                    ($grad_type == 'master' && strtolower(substr($program->program_name, 0, strlen('Master of '))) == 'master of '))
                                                    {
//				                                        if ($program->faculty_id == $faculty->faculty_id &&
//				                                            $program->program_research_coursework == $faculty->program_research_coursework &&
//				                                            $program->program_research_coursework == $study_mode)
//				                                        {
                                                        if ($program->faculty_id == $faculty->faculty_id &&
                                                            $program->program_option_id == $faculty->program_option_id &&
                                                            $program->program_option_id == $study_mode)
                                                        {
                                                            $program_count++;

                                                            $output .= '<tr>';
                                                            $output .= '<td style="text-align: center;">' . $program_count . '</td>';

                                                            $output .= '<td>';

                                                            if ($program->program_scope == 'L')
                                                            {
                                                                $output .= '<span style="color:red;">*</span>&nbsp;';
                                                                $count_local++;
                                                            }

                                                            if ( ! empty($program->program_code))
                                                            {
                                                                $output .= $program->program_code . ': ';
                                                            }

                                                            $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                                                            $output .= $program->program_name;
                                                            $output .= '</a>';

                                                            if ($program->program_is_new == '1')
                                                            {
                                                                $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                                                                $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                                                                $tag .= __('New');
                                                                $tag .= '</span>';
                                                                $tag .= '[/highlight]';

                                                                $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                                                            }

                                                            $output .= '</td>';

                                                            if ($srow == 1)
                                                            {
                                                                if ($study_mode_row ==0 OR $study_mode_row % 2 == 0)
                                                                {
                                                                    $output .= '<td rowspan="' . $study_mode_count[$study_mode] . '" style="background-color: #ffffff;">';
                                                                }
                                                                else
                                                                {
                                                                    $output .= '<td rowspan="' . $study_mode_count[$study_mode] . '" style="background-color: #f6f6f6;">';
                                                                }
                                                                $output .= $study_mode_title[$study_mode];
                                                                $output .= '</td>';
                                                            }

                                                            // Using rowspan
                                                            if ($row == 1)
                                                            {
                                                                if ($faculty_row == 0 OR $faculty_row % 2 == 0)
                                                                {
                                                                    $output .= '<td rowspan="' . $faculty->program_count . '" style="background-color: #ffffff;">';	// rowspan required for styling (even for 1 row)
                                                                }
                                                                else
                                                                {
                                                                    $output .= '<td rowspan="' . $faculty->program_count . '" style="background-color: #f6f6f6;">';	// rowspan required for styling (even for 1 row)
                                                                }
                                                                $output .= ( ! empty($faculty->faculty_name) ? $faculty->faculty_name : '&nbsp;');
                                                                $output .= '</td>';

                                                                $faculty_row++;
                                                            }

                                                            $output .= '</tr>' . "\n";
                                                            $row++;
                                                            $srow++;
                                                        }

                                                    }
                                            }
                                        }
                                    }
                                    $study_mode_row++;
                                }
                                $output .= '</tbody>' . "\n";
                                $output .= '</table>' . "\n";
                                $output .= '</div>' . "\n";
                                $output .= '<br>';
                            }
                        }
                    }
                    else if ($studylevel->studylevel_id == '12')
                    {
                        // Undergraduate Studies

                        $output .= "\n";
                        $output .= '<div class="table-1">';
                        $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                        $output .= '<thead>';
                        $output .= '<tr>';
                        $output .= '<th style="width: 5%;">&nbsp;</th>';
                        $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                        $output .= '<th style="width: 45%;">' . __('Faculty', 'course-catalog-system') . '</th>';
                        $output .= '</tr>';
                        $output .= '</thead>' . "\n";
                        $output .= '<tbody>' . "\n";

                        $program_count = 0;
                        $faculty_row = 0;

                        foreach ($faculties as $faculty)
                        {
                            if ( ! empty($faculty->faculty_name))
                            {
                                $row = 1;

                                foreach ($programs as $program)
                                {
                                    if ($program->faculty_id == $faculty->faculty_id)
                                    {
                                        $program_count++;

                                        $output .= '<tr>';
                                        $output .= '<td style="text-align: center;">' . $program_count . '</td>';

                                        $output .= '<td>';

                                        if ($program->program_scope == 'L')
                                        {
                                            $output .= '<span style="color:red;">*</span>&nbsp;';
                                            $count_local++;
                                        }
                                        if ( ! empty($program->program_code))
                                        {
                                            $output .= $program->program_code . ': ';
                                        }

                                        $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                                        $output .= $program->program_name;
                                        $output .= '</a>';

                                        if ($program->program_is_new == '1')
                                        {
                                            $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                                            $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                                            $tag .= __('New');
                                            $tag .= '</span>';
                                            $tag .= '[/highlight]';

                                            $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                                        }

                                        $output .= '</td>';

                                        if ($row == 1)
                                        {
                                            if ($faculty_row % 2 == 0)
                                            {
                                                $output .= '<td rowspan="' . $faculty->program_count . '" style="background-color: #ffffff;">';		// rowspan required for styling (even for 1 row)
                                            }
                                            else
                                            {
                                                $output .= '<td rowspan="' . $faculty->program_count . '" style="background-color: #f6f6f6;">';		// rowspan required for styling (even for 1 row)
                                            }
                                            $output .= $faculty->faculty_name;
                                            $output .= '</td>';
                                            $faculty_row++;
                                        }

                                        $output .= '</tr>' . "\n";
                                        $row++;
                                    }
                                }
                                $output .= '</tr>' . "\n";
                            }
                        }

                        $output .= '</tbody>' . "\n";
                        $output .= '</table>' . "\n";
                        $output .= '</div>' . "\n";
                        $output .= '<br>';

                    }
                    else
                    {
                        // Advanced Diploma & Tamhidi only

                        $output .= "\n";
                        $output .= '<div class="table-1">';
                        $output .= '<table class="ccs-program-table" width="100%">' . "\n";
                        $output .= '<thead>';
                        $output .= '<tr>';
                        $output .= '<th style="width: 5%;">&nbsp;</th>';
                        $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                        $output .= '</tr>';
                        $output .= '</thead>' . "\n";
                        $output .= '<tbody>' . "\n";

                        $program_count = 0;

                        foreach ($faculties as $faculty)
                        {
                            $row = 1;

                            foreach ($programs as $program)
                            {
                                if ($program->faculty_id == $faculty->faculty_id)
                                {
                                    $program_count++;

                                    $output .= '<tr>';
                                    $output .= '<td style="text-align: center;">' . $program_count . '</td>';

                                    $output .= '<td>';
                                    if ($program->program_scope == 'L')
                                    {
                                        $output .= '<span style="color:red;">*</span>&nbsp;';
                                        $count_local++;
                                    }
                                    if ( ! empty($program->program_code))
                                    {
                                        $output .= $program->program_code . ': ';
                                    }

                                    $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                                    $output .= $program->program_name;
                                    $output .= '</a>';

                                    if ($program->program_is_new == '1')
                                    {
                                        $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                                        $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                                        $tag .= __('New');
                                        $tag .= '</span>';
                                        $tag .= '[/highlight]';

                                        $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                                    }

                                    $output .= '</td>';
                                    $output .= '</tr>' . "\n";
                                    $row++;
                                }
                            }
                        }

                        $output .= '</tbody>' . "\n";
                        $output .= '</table>' . "\n";
                        $output .= '</div>';
                        $output .= '<br>';
                    }
                }

                $output .= '[/fusion_tab]';
            }
        }
        $output .= '[/fusion_tabs]';

        $output = do_shortcode($output);

        if ($count_local > 0)
        {
            $output .= '<div class="ccs-text">';
            if ($count_local == 1)
            {
                $output .= __('Programme marked (', 'course-catalog-system');
            }
            else
            {
                $output .= __('Programmes marked (', 'course-catalog-system');
            }
            $output .= '<span style="color:red;">*</span>';
            if ($count_local == 1)
            {
                $output .= __(') is not available for international students', 'course-catalog-system');
            }
            else
            {
                $output .= __(') are not available for international students', 'course-catalog-system');
            }
            $output .= '</div>';
        }
        $output .= '<br>';
        $output = $output . do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('Search Program', 'course-catalog-system') . '[/button]');

        $faculty_name = __('All Programmes', 'course-catalog-system');
    }
    else
    {
        // Faculty Programmes

        $remote_url = $options['ccs_url'] . '/api/wordpress/faculty_programs_count/' . $fid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $programs_count = json_decode($json_data);

        $current_faculty = '';
        $faculty_count = 0;

        if (count($programs_count) > 0)
        {
            $remote_url = $ccs_url . '/api/wordpress/faculty_programs/' . $fid . '/' . $lang;
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $programs = json_decode($json_data);

            $output .= '<div class="table-1">';
            $output .= '<table class="ccs-program-table" width="100%">' . "\n";
            $output .= '<thead>';
            $output .= '<tr>';
            $output .= '<th style="width: 5%;">&nbsp;</th>';
            $output .= '<th>' . __('Level of Study', 'course-catalog-system') . '</th>';
            $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
            $output .= '<th>' . __('Program Option', 'course-catalog-system') . '</th>';
            $output .= '</tr>';
            $output .= '</thead>' . "\n";
            $output .= '<tbody>' . "\n";

            $count_local = 0;
            $idx = 1;

            // Loop all studylevels
            foreach ($programs_count as $prg_cnt)
            {
                if ($prg_cnt->faculty_name != $current_faculty)
                {
                    $faculty_count++;
                    $current_faculty = $prg_cnt->faculty_name;

                    if (empty($faculty_name))
                    {
                        $faculty_name = $prg_cnt->faculty_name;
                    }
                }

                if ($prg_cnt->program_count > 0)
                {
                    $row = 0;

                    $current_faculty = '';
                    $prog_count = 0;

                    $output .= '<tr>';

                    if ($row == 0)
                    {
                        $output .= '<td style="text-align: center;">' . $idx . '</td>';

                        $output .= '<td rowspan="' . $prg_cnt->program_count . '" style="background-color: #ffffff;">';
                        if ($fid == 'all')
                        {
                            if ( ! empty($prg_cnt->faculty_name))
                            {
                                $output .= $prg_cnt->faculty_name;
                            }
                        }
                        else
                        {
                            $output .= $prg_cnt->studylevel_name;
                        }
                        $output .= '</td>';
                    }

                    // Loop all programs
                    foreach ($programs as $program)
                    {
                        $prog_count++;
                        if ($prog_count > $prg_cnt->program_count)
                        {
                            //break;
                        }

                        if ($program->faculty_id == $prg_cnt->faculty_id && $program->studylevel_id == $prg_cnt->studylevel_id)
                        {
                            if ( ! empty($current_faculty) && $current_faculty != $program->faculty_id)
                            {
                                break;
                            }

                            if ($row > 0)
                            {
                                $output .= '<td style="text-align: center;">' . $idx . '</td>';
                            }

                            $output .= '<td>';

                            if ($program->program_scope == 'L')
                            {
                                $output .= '<span style="color:red;">*</span>&nbsp;';
                                $count_local++;
                            }

                            $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                            if ( ! empty($program->program_code))
                            {
                                $output .= $program->program_code . ': ';
                            }
                            $output .= $program->program_name;
                            $output .= '</a>';

                            if ($program->program_is_new == '1')
                            {
                                $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                                $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                                $tag .= __('New');
                                $tag .= '</span>';
                                $tag .= '[/highlight]';

                                $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                            }

                            $output .= '</td>';

                            $output .= '<td>';
                            if ($program->program_research_coursework == '10')
                            {
                                $output .= __('By Research', 'course-catalog-system');
                            }
                            else if ($program->program_research_coursework == '1000')
                            {
                                $output .= __('By Coursework', 'course-catalog-system');
                            }
                            else if ($program->program_research_coursework == '1010')
                            {
                                $output .= __('By Mixed Mode', 'course-catalog-system');
                            }
                            else
                            {
                                $output .= '&nbsp;';
                            }
                            $output .= '</td>';
                            $output .= '</tr>' . "\n";

                            $row++;
                            $idx++;
                            $current_faculty = $program->faculty_id;
                        }
                    }
                }
            }

            $output .= '</tbody>' . "\n";
            $output .= '</table>' . "\n";
            $output .= '</div>' . "\n";

            $output .= '<br>';
            $output .= '<div class="ccs-text">';
            $output .= __('Programme marked (', 'course-catalog-system');
            $output .= '<span style="color:red;">*</span>';
            $output .= __(') are not available for international students', 'course-catalog-system');
            $output .= '</div>';
            $output .= '<br>';

            $output = $output . do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('Search Program', 'course-catalog-system') . '[/button]');
        }
        else
        {
            $output .= __('No Programme found');
            $remote_url = $ccs_url . '/api/wordpress/faculty/' . $fid . '/' . $lang;
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $program = json_decode($json_data);

            $faculty_name = $program->faculty_name;
        }
    }

    $output .= '<script type="text/javascript">';
    if ( ! empty($faculty_name))
    {
        $output .= "var page_title = jQuery('.fusion-page-title-captions > .entry-title');";
        $output .= "page_title.html('" . $faculty_name . "');" ;
        $output .= "page_title.css('text-transform', 'uppercase');";
    }
    $output .= '</script>';

    $output .= "\n";

    return $output . eol();
}
add_shortcode('ccs_render_faculty_program_list', 'ccs_render_faculty_program_list');

function ccs_render_program_details()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_tag_background_color = $options['ccs_tag_background_color'];
    if (empty($ccs_tag_background_color)) $ccs_tag_background_color = CCS_TAG_BGCOLOR;
    $ccs_tag_color = $options['ccs_tag_color'];
    if (empty($ccs_tag_color)) $ccs_tag_color = CCS_TAG_COLOR;

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/details/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $details = json_decode($json_data);		// Program details

        if (count($details) > 0)
        {
            $row = $details[0];

            $content = do_shortcode('[tagline_box highlightposition="top" margin_bottom="20px"]<h2>' . $row->program_name . '</h2>[/tagline_box]');

            $output .= $content;

            $content  = '<h3>' . __('PROGRAM DETAILS', 'course-catalog-system') . '</h3>';
            $content .= '<strong>' . __('Medium of instructions: ', 'course-catalog-system') . '</strong>';

            $i = 0;
            $program_mediums = $row->program_mediums;
            foreach ($program_mediums as $medium)
            {
                if ($i > 0)
                {
                    if ($i == count($program_mediums) - 1)
                    {
                        $content .= ' ' . __('and', 'course-catalog-system') . ' ';
                    }
                    else
                    {
                        $content .= ', ';
                    }
                }

                $content .= $medium;

                $i++;
            }

            $content .= '<br>';
            if ( ! empty($row->program_credithour) && $row->program_credithour > 0)
            {
                $content .= '<strong>' . __('Credit hours: ', 'course-catalog-system') . '</strong>' . $row->program_credithour . '<br>';
            }

            $remote_url = $ccs_url . '/api/wordpress/program_durations/' . $pid . '/' . $lang;
            $response = ccs_get_content_curl($remote_url);

            $json_data = $response['html'];
            $durations = json_decode($json_data);		// Program details

            if (count($durations) > 0)
            {
                $actual_count = 0;

                foreach ($durations as $duration)
                {
                    if ( ! empty($duration->program_duration_year) OR  ! empty($duration->program_duration_semester))
                    {
                        $actual_count++;
                    }
                }

                if ($actual_count > 0)
                {
                    $content .= '<strong>' . __('Duration of Studies: ', 'course-catalog-system') . '</strong>' . '<br>';

                    foreach ($durations as $duration)
                    {
                        if ( ! empty($duration->program_duration_year) OR  ! empty($duration->program_duration_semester))
                        {
                            if ($duration->program_type_code == 'F')
                            {
                                $content .= '- ' . __('Full Time', 'course-catalog-system') . ': ';
                            }
                            else if ($duration->program_type_code == 'P')
                            {
                                $content .= '- ' . __('Part Time', 'course-catalog-system') . ': ';
                            }

                            if ( ! empty($duration->program_duration_year))
                            {
                                $content .= $duration->program_duration_year . ' ' . __('years', 'course-catalog-system');
                                if ( ! empty($duration->program_duration_semester))
                                {
                                    $content .= ' (' . $duration->program_duration_semester . ' ' . __('semesters', 'course-catalog-system') . ')';
                                }
                            }
                            else
                            {
                                $content .= $duration->program_duration_semester . ' ' . __('semesters', 'course-catalog-system');
                            }
                            $content .= '<br>';
                        }
                    }
                    //$content .= '<br>';
                }

            }

            if ( ! empty($row->program_option_name))
            {
                $content .= '<strong>' . __('Programme Option: ', 'course-catalog-system') . '</strong>';
                $content .= $row->program_option_name . '<br>';
            }

            $program_description = trim(strip_tags($row->program_description));
            $program_description = str_replace('&nbsp;', '', $program_description);
            $program_careerprospect = trim(strip_tags($row->program_careerprospect));
            $program_careerprospect = str_replace('&nbsp;', '', $program_careerprospect);

            if ( ! empty($program_description) ||  ! empty($program_careerprospect))
            {
                $content .= '<br>';
            }

            if ( ! empty($program_description))
            {
                $content .= $row->program_description;
            }

            if ( ! empty($program_careerprospect))
            {
                $content .= '<h3>' . __('CAREER PROSPECTS', 'course-catalog-system') . '</h3>';
                $content .= $row->program_careerprospect;
            }

            if ( ! empty($row->program_tags))
            {
                $tags = explode(',', $row->program_tags);

                if (count($tags) > 0)
                {
                    $content .= '<br><p>' . __('Tags: ');

                    foreach ($tags as $tag)
                    {
                        $content .= '<span class="fusion-highlight light highlight1" style="background-color:' . $ccs_tag_background_color . ';">' .
                                    '<span style="color: ' . $ccs_tag_color . ';">' . $tag . '</span>' .
                                    '</span>&nbsp;';
                    }

                    $content .= '</p>';
                }
            }

            $content = do_shortcode('[tagline_box highlightposition="top" margin_bottom="20px"]' .
                        $content .
                        '[/tagline_box]');

            if ($row->program_scope == 'L')
            {
                $content .= '<span style="color:red;">*</span> <em>' . __('This programme is not available for international students', 'course-catalog-system') . '</em>';
                $content .= '<br><br>';
            }

            $output .= $content;

            $css  = '<style type="text/css">';
            $css .= '.fusion-tabs.vertical-tabs .nav-tabs { width: 20% } ';
            $css .= '.fusion-tabs.vertical-tabs .tab-content { width: 80% } ';
            $css .= '</style>';

            $output = $css . $output;

            $output .= '<script type="text/javascript">';
            $output .= "var page_title = jQuery('.fusion-page-title-captions > .entry-title');";
            $output .= "page_title.html('" . $row->studylevel_name . "');" ;
            $output .= "page_title.css('text-transform', 'uppercase');";
            $output .= '</script>';

        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_details', 'ccs_render_program_details');

function ccs_render_program_requirements()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_local_tab_icon = $options['ccs_local_tab_icon'];
    $ccs_intl_tab_icon = $options['ccs_intl_tab_icon'];
    $ccs_all_tab_icon = $options['ccs_all_tab_icon'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_requirements/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        $top = '';

        if (count($requirements) > 0)
        {
            $tab_title = '';
            $scope_classes = array();

            foreach ($requirements as $scope => $requirement_list)
            {
                $tab_title = '';
                $scope_class = '';

                switch ($scope)
                {
                    case 'L':
                        $tab_title = __('Local Students', 'course-catalog-system');
                        $scope_class = 'local';
                        $scope_classes[] = $scope_class;
                        break;
                    case 'I':
                        $tab_title = __('International Students', 'course-catalog-system');
                        $scope_class = 'international';
                        $scope_classes[] = $scope_class;
                        break;
                    case 'B':
                        $tab_title = '';
                        break;
                }

                if ( ! empty($tab_title))
                {
                    $output .= '[fusion_tab title="' . $tab_title . '"';
                }

                if ($scope == 'L')
                {
                    if ( ! empty($tab_title))
                    {
                        $output .= ( ! empty($ccs_local_tab_icon) ? ' icon="' . $ccs_local_tab_icon . '"' : '');
                    }
                }
                else if ($scope == 'I')
                {
                    if ( ! empty($tab_title))
                    {
                        $output .= ( ! empty($ccs_intl_tab_icon) ? ' icon="' . $ccs_intl_tab_icon . '"' : '');
                    }
                }
                else if ($scope == 'B')
                {
                    if ( ! empty($tab_title))
                    {
                        $output .= ( ! empty($ccs_all_tab_icon) ? ' icon="' . $ccs_all_tab_icon . '"' : '');
                    }
                }

                if ( ! empty($tab_title))
                {
                    $output .= ']';
                }

                $contents = '';

                if (count($requirement_list) > 0)
                {
                    $contents .= '[accordian divider_line="no"]';
                    $specific_req = false;

                    foreach ($requirement_list as $requirement)
                    {
                        $contents  .= '[toggle title="' . $requirement->requirement_type_name . '" open="no"]';
                        if ( ! isset($requirement->rows))
                        {
                            // Requirement content
                            $contents .= do_shortcode($requirement->requirement_description);
                        }
                        else
                        {
                            if ( ! empty($requirement->rows[0]->admission_type_name))
                            {
                                // Admission type
                                $tabcontent = '[fusion_tabs design="classic" layout="vertical"]';
                                foreach ($requirement->rows as $row)
                                {
                                    $tabcontent .= '[fusion_tab title="' . $row->admission_type_name . '"]';
                                    // Generic/Specific requirement content
                                    $tabcontent .= do_shortcode($row->requirement_description);
                                    $tabcontent .= '[/fusion_tab]';
                                }
                                $tabcontent .= '[/fusion_tabs]';

                                $contents .= do_shortcode($tabcontent);
                            }
                            else
                            {
                                // Non-admission type
                                foreach ($requirement->rows as $row)
                                {
                                    $contents .= do_shortcode($row->requirement_description);
                                }
                            }
                        }
                        $contents .= '[/toggle]';
                    }

                    $contents .= '[/accordian]';

                    $output .= do_shortcode($contents);
                }

                if ( ! empty($tab_title))
                {
                    $output .= '[/fusion_tab]';
                }
            }

            if ( ! empty($tab_title))
            {
                $output = '[fusion_tabs design="classic" layout="horizontal" justified="yes" class="ccs-tabs"]' . $output . '[/fusion_tabs]';
            }
            else
            {
                $output = '[tagline_box highlightposition="top" backgroundcolor="#ffffff" border="1px" margin_bottom="20px"]' . $output . '[/tagline_box]';
            }

            $output = do_shortcode($output);

            $output .= '<script type="text/javascript">';
            $output .= "var border_color = jQuery('.fusion-tabs > .nav').css('border-top-color');";
            $output .= "jQuery('.ccs-tabs .toggle-content > p').css('margin-bottom', '0px');";
            $output .= "jQuery('.ccs-tabs .fusion-tabs').css('margin-bottom', '0px');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-right-width', '1px');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-right-style', 'solid');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-right-color', border_color);";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-bottom-width', '1px');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-bottom-style', 'solid');";
            $output .= "jQuery('.ccs-tabs .tab-content > .tab-pane').css('border-bottom-color', border_color);";
            //$output .= "jQuery('.vertical-tabs > .nav > .nav-tabs > li:first').addClass('active')";

            $child_index = 0;
            foreach ($scope_classes as $scope_class)
            {
                $child_index++;
//                $output .= "jQuery('.ccs-tabs > .nav > .nav-tabs > li:nth-child(" . $child_index . ") > .tab-link').addClass('tab-" . $scope_class . "');";
//                $output .= "jQuery('.ccs-tabs > .tab-content > .tab-pane:eq(" . ($child_index - 1) . ")').addClass('content-" . $scope_class . "');";
//                $output .= "jQuery('.ccs-tabs > .tab-content > .tab-pane:eq(" . ($child_index - 1) . ")').find('.tab-link').addClass('vtab-" . $scope_class . "');";
//                $output .= "jQuery('.vtab-" . $scope_class . "').on('click', function() {";
//                //$output .= "jQuery('.tab-" . $scope_class . "').parent().addClass('active');";
//                //$output .= "jQuery('.tab-" . $scope_class . "').show();";
//                $output .= "console.log('Parent: ' + jQuery('.tab-" . $scope_class . " > h4').text());";
//                $output .= "});";

                $output .= "jQuery('.ccs-tabs > .nav > .nav-tabs > li:nth-child(" . $child_index . ") > .tab-link').addClass('tab-" . $scope_class . "');";
                $output .= "jQuery('.ccs-tabs > .tab-content > .tab-pane:eq(" . ($child_index - 1) . ")').find('.tab-link').addClass('vtab-" . $scope_class . "');";
                $output .= "jQuery(document).ready(function() {";
                $output .= "jQuery('.vtab-" . $scope_class . "').on('click', function() {";
                $output .= "function forceSelectTab() {";
                $output .= "jQuery('.tab-" . $scope_class . "').tab('show');";
                $output .= "jQuery('.tab-" . $scope_class . "').parent().addClass('active');";
                $output .= "}";
                $output .= "window.setTimeout(forceSelectTab, 0);";
                $output .= "});";
                $output .= "});";
            }

            $output .= '</script>';

        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_requirements', 'ccs_render_program_requirements');

function ccs_render_program_common_requirements()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_adm_tab_icon = $options['ccs_adm_tab_icon'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_common_requirements/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        if (count($requirements) > 0)
        {
            $output .= '[fusion_tabs design="classic" layout="horizontal" justified="yes" class="ccs-tabs"]';
            $tab_title = __('Admission Requirements', 'course-catalog-system');
            $output .= '[fusion_tab title="' . $tab_title . '"';
            if ( ! empty($ccs_adm_tab_icon))
            {
                $output .= ' icon="' . $ccs_adm_tab_icon . '"';
            }
            $output .= ']';

            $scopes = array('B');

            foreach ($scopes as $scope)
            {
                if (isset($requirements->$scope))
                {
                    $output .= $requirements->$scope;
                }
            }

            $output .= '[/fusion_tab]';
            $output .= '[/fusion_tabs]';

            $output = do_shortcode($output);

            $output .= '<script type="text/javascript">';
            $output .= "jQuery('.ccs-tabs-common > .tab-content > .tab-pane > p:last-of-type').css('margin-bottom', '10px');";
            $output .= '</script>';
        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_common_requirements', 'ccs_render_program_common_requirements');

function ccs_render_program_contact_us()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_contact_us/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        if (count($requirements) > 0)
        {
            $output .= '[tagline_box highlightposition="top" margin_bottom="20px" title="' . __('Contact Us', 'course-catalog-system') . '"]';

            $scopes = array('L', 'I');

            $contact_cnt = 0;

            foreach ($scopes as $scope)
            {
                if (isset($requirements->$scope))
                {
                    $contact_cnt++;

                    if ($contact_cnt > 1)
                    {
                        $output .= '<br>';
                    }

                    $output .= $requirements->$scope;
                }
            }

            $output .= '[/tagline_box]';

            $output = do_shortcode($output);
        }
    }

    if ( ! empty($output))
    {
        return $output . eol();
    }
    else
    {
        return '';
    }
}
add_shortcode('ccs_render_program_contact_us', 'ccs_render_program_contact_us');

function ccs_render_program_whats_next()
{
     if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/program_whats_next/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $requirements = json_decode($json_data);		// Program details

        if (count($requirements) > 0)
        {
            $output .= '[tagline_box highlightposition="top" margin_bottom="20px" title="' . __('What To Do Next', 'course-catalog-system') . '"]';

            $scopes = array('L', 'I');

            $contact_cnt = 0;

            foreach ($scopes as $scope)
            {
                if (isset($requirements->$scope))
                {
                    $contact_cnt++;

                    if ($contact_cnt > 1)
                    {
                        $output .= '<br>';
                    }

                    $output .= '<h3>' . ($scope == 'L' ? __('Local Students', 'course-catalog-system') : __('International Students', 'course-catalog-system')) . '</h3>';
                    $output .= $requirements->$scope;
                }
            }

            $output .= '[/tagline_box]';

            $output = do_shortcode($output);
        }
    }

    if ( ! empty($output))
    {
        return $output . eol();
    }
    else
    {
        return '';
    }
}
add_shortcode('ccs_render_program_whats_next', 'ccs_render_program_whats_next');

function ccs_render_program_requirement_type($atts)
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    if ( ! empty($atts))
    {
        $attributes = shortcode_atts(array(
            'code' => '',
            'title' => ''
        ), $atts);
    }
    else
    {
        $attributes['code'] = '';
        $attributes['title'] = '';
    }

    $output = '';

    if ( ! empty($attributes['code']))
    {
        // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
        // Each __() function must be __('Words to translate', 'course-catalog-system')
        load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

        $options = get_option(CCS_OPTION_NAME);
        $ccs_url = $options['ccs_url'];
        $ccs_program_id_param = $options['ccs_program_id_param'];

        $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

        $codes = explode(',', $attributes['code']);
        $title = $attributes['title'];

        if ( ! empty($pid) && count($codes) > 0)
        {
            foreach ($codes as $code)
            {
                $remote_url = $ccs_url . '/api/wordpress/program_requirement_type/' . trim($code) . '/' . $pid . '/' . $lang;
                $response = ccs_get_content_curl($remote_url);

                $json_data = $response['html'];
                $requirements = json_decode($json_data);		// Program details

                if (count($requirements) > 0)
                {
                    $scopes = array('L', 'I', 'B');

                    $req_type_cnt = 0;

                    foreach ($scopes as $scope)
                    {
                        if (isset($requirements->$scope))
                        {
                            $req_type_cnt++;

                            if ($req_type_cnt > 1)
                            {
                                $output .= '<br>';
                            }

                            $data = $requirements->$scope;

                            $output .= ( ! empty($data->title) ? '<h2>' . $data->title . '</h2>' : '');
                            $output .= ( ! empty($data->text) ? $data->text : '');
                        }
                    }
                }
            }

            if ( ! empty($output))
            {
                if ( ! empty($title))
                {
                    $output = '[tagline_box highlightposition="top" margin_bottom="20px" title="' . __($title, 'course-catalog-system') . '"]' . $output . '[/tagline_box]';
                }
                else
                {
                    $output = '[tagline_box highlightposition="top" margin_bottom="20px"]' . $output . '[/tagline_box]';
                }
                $output = do_shortcode($output);
            }
        }
    }

    if ( ! empty($output))
    {
        return $output . eol();
    }
    else
    {
        return '';
    }
}
add_shortcode('ccs_render_program_requirement_type', 'ccs_render_program_requirement_type');

/**
 * Get program testimonial
 */
function ccs_render_testimonial()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_id_param = $options['ccs_program_id_param'];

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid))
    {
        $remote_url = $ccs_url . '/api/wordpress/testimonial/' . $pid . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $testimonials = json_decode($json_data);

        $testimonial_count = 0;

        if (count($testimonials) > 0)
        {
            if (count($testimonials) == 1)
            {
                $output .= '[tagline_box highlightposition="top" margin_bottom="20px" title="' . __('Testimonial', 'course-catalog-system') . '" class="ccs-testimonial"]';
            }
            else
            {
                $output .= '[tagline_box highlightposition="top" margin_bottom="20px" title="' . __('Testimonials', 'course-catalog-system') . '" class="ccs-testimonial"]';
            }

            foreach ($testimonials as $testimonial)
            {
                if ($testimonial_count > 1)
                {
                    $output .= '<hr>';
                }
                $output .= '<img src="' . $testimonial->photo_url . '" alt="">';
                $output .= '<img src="' . plugins_url('images/quote.png', __FILE__) . '" alt="">' . '<br>';

                if ( ! empty($testimonial->testimonial_quote))
                {
                    $output .= '<span class="ccs-testimonial-quote">' . $testimonial->testimonial_quote . '</span>';
                }
                $output .= '[person name="' . $testimonial->testimonial_name . '" title="(' . $testimonial->testimonial_position . ')"][/person]';

                if (count($testimonial->education) > 0)
                {
                    $output .= '<span class="ccs-education-title">' . __('Education:', 'course-catalog-system') . $testimonial->testimonial_education . '</h4>';
                    $output .= '<ul class="ccs-education-list">';

                    foreach ($testimonial->education as $education)
                    {
                        if ($education->is_usim == '1')
                        {
                            $output .= '<li class="ccs-education-usim">' . $education->testimonial_education . '</li>';
                        }
                        else
                        {
                            $output .= '<li>' . $education->testimonial_education . '</li>';
                        }
                    }
                    $output .= '</ul>';
                }

                $testimonial_count++;
            }

            $output .= '[/tagline_box]';

            return do_shortcode($output) . eol();
        }
    }

    return eol();
}
add_shortcode('ccs_render_testimonial', 'ccs_render_testimonial');

function ccs_render_search_program()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_details_page = $options['ccs_program_details_page'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_program_search_page = $options['ccs_program_search_page'];
    $ccs_program_search_result_page = $options['ccs_program_search_result_page'];

    if (empty($ccs_program_search_result_page))
    {
        if ( ! empty($ccs_program_search_page))
        {
            $ccs_program_search_result_page = $ccs_program_search_page;
        }
    }

    $ccs_tag_new_background_color = $options['ccs_tag_new_background_color'];
    if (empty($ccs_tag_new_background_color)) $ccs_tag_new_background_color = CCS_TAG_NEW_BGCOLOR;
    $ccs_tag_new_color = $options['ccs_tag_new_color'];
    if (empty($ccs_tag_new_color)) $ccs_tag_new_color = CCS_TAG_NEW_COLOR;

    $output = '';

    if ( ! isset($_GET['query']))
    {
        // Get faculty list
        $remote_url = $ccs_url . '/api/wordpress/faculties/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $faculties = json_decode($json_data);

        $faculty_list = '';
        foreach ($faculties as $faculty)
        {
            if ( ! get_post_value('faculty_id'))
            {
                $faculty_list .= '<option value="' . $faculty->faculty_id .  '">' . $faculty->faculty_name . '</option>';
            }
            else
            {
                $faculty_list .= '<option value="' . $faculty->faculty_id .  '"' . (get_post_value('faculty_id') == $faculty->faculty_id ? ' selected="selected"' : '') . '>' . $faculty->faculty_name . '</option>';
            }
        }

        // Get studylevel list
        $remote_url = $ccs_url . '/api/wordpress/studylevels/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $studylevels = json_decode($json_data);

        $studylevel_list = '';
        foreach ($studylevels as $studylevel)
        {
            if ( ! get_post_value('studylevel_id'))
            {
                $studylevel_list .= '<option value="' . $studylevel->studylevel_id .  '">' . $studylevel->studylevel_name . '</option>';
            }
            else
            {
                $studylevel_list .= '<option value="' . $studylevel->studylevel_id .  '"' . (get_post_value('studylevel_id') == $studylevel->studylevel_id ? ' selected="selected"' : '') . '>' . $studylevel->studylevel_name . '</option>';
            }
        }

        $remote_url = $ccs_url . '/api/wordpress/search_config';
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $search_fields = json_decode($json_data);

        // -- Search form init start

        $output  = '<form method="post" id="ccs_search_form" name="ccs_search_form" class="ccs-form" action="#result" autocomplete="off">';

        foreach ($search_fields as $field)
        {
            if ($field->name == 'program_code')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_code">';
                $output .= '' . __('Programme Code', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="program_code_filter" name="program_code_filter" style="width: 100%;">';
                $output .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                $output .= '<option value="eq"' . (get_post_value('program_code_filter') == 'eq' ? ' selected="selected"' : '') . '>' . __('Equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="ne"' . (get_post_value('program_code_filter') == 'ne' ? ' selected="selected"' : '') . '>' . __('Not equal to', 'course-catalog-system') . '</option>';
                $output .= '<option value="sw"' . (get_post_value('program_code_filter') == 'sw' ? ' selected="selected"' : '') . '>' . __('Starts with', 'course-catalog-system') . '</option>';
                $output .= '<option value="ew"' . (get_post_value('program_code_filter') == 'ew' ? ' selected="selected"' : '') . '>' . __('Ends with', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-2">';
                $output .= '<input type="text" id="program_code" name="program_code"' . (get_post_value('program_code') ? ' value="' . get_post_value('program_code') . '"' : '') . '>';
                $output .= '</div>';
                $output .= '<div class="hidden-sm col-md-5">&nbsp;</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'program_name')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_name">';
                $output .= '' . __('Programme Name', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="program_name_filter" name="program_name_filter" style="width: 100%;">';
                $output .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                $output .= '<option value="eq"' . (get_post_value('program_name_filter') == 'eq' ? ' selected="selected"' : '') . '>' . __('Equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="ne"' . (get_post_value('program_name_filter') == 'ne' ? ' selected="selected"' : '') . '>' . __('Not equal to', 'course-catalog-system') . '</option>';
                $output .= '<option value="sw"' . (get_post_value('program_name_filter') == 'sw' ? ' selected="selected"' : '') . '>' . __('Starts with', 'course-catalog-system') . '</option>';
                $output .= '<option value="ew"' . (get_post_value('program_name_filter') == 'ew' ? ' selected="selected"' : '') . '>' . __('Ends with', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-6">';
                $output .= '<input type="text" id="program_name" name="program_name"' . (get_post_value('program_name') ? ' value="' . get_post_value('program_name') . '"' : '') . '>';
                $output .= '</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'faculty_id')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 faculty_id">';
                $output .= '' . __('Faculty', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="faculty_id_filter" name="faculty_id_filter" style="width: 100%;">';
                $output .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="ne"' . (get_post_value('faculty_id_filter') == 'ne' ? ' selected="selected"' : '') . '>' . __('Not equal to', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-6">';
                $output .= '<select id="faculty_id" name="faculty_id">';
                $output .= '<option value="">&nbsp;</option>';
                $output .= $faculty_list;
                $output .= '</select>';
                $output .= '</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'studylevel_id')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 studylevel_id">';
                $output .= '' . __('Level of Study', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="studylevel_id_filter" name="studylevel_id_filter" style="width: 100%;">';
                $output .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="ne"' . (get_post_value('studylevel_id_filter') == 'ne' ? ' selected="selected"' : '') . '>' . __('Not equal to', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-3">';
                $output .= '<select id="studylevel_id" name="studylevel_id">';
                $output .= '<option value="">&nbsp;</option>';
                $output .= $studylevel_list;
                $output .= '</select>';
                $output .= '</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'program_credithour')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_credithour">';
                $output .= '' . __('Credit Hours', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="program_credithour_filter" name="program_credithour_filter" style="width: 100%;">';
                $output .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="ne"' . (get_post_value('program_credithour_filter') == 'ne' ? ' selected="selected"' : '') . '>' . __('Not equal to', 'course-catalog-system') . '</option>';
                $output .= '<option value="lt"' . (get_post_value('program_credithour_filter') == 'lt' ? ' selected="selected"' : '') . '>' . __('Less than', 'course-catalog-system') . '</option>';
                $output .= '<option value="le"' . (get_post_value('program_credithour_filter') == 'le' ? ' selected="selected"' : '') . '>' . __('Less than or equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="gt"' . (get_post_value('program_credithour_filter') == 'gt' ? ' selected="selected"' : '') . '>' . __('Greater than', 'course-catalog-system') . '</option>';
                $output .= '<option value="ge"' . (get_post_value('program_credithour_filter') == 'ge' ? ' selected="selected"' : '') . '>' . __('Greater than or equals to', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-2">';
                $output .= '<input type="text" id="program_credithour" name="program_credithour" maxlength="2"' . (get_post_value('program_credithour') ? ' value="' . get_post_value('program_credithour') . '"' : '') . '>';
                $output .= '</div>';
                $output .= '<div class="hidden-sm col-md-5">&nbsp;</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'program_duration')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_duration">';
                $output .= '' . __('Programme Length', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="program_duration_filter" name="program_duration_filter" style="width: 100%;">';
                $output .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="ne"' . (get_post_value('program_duration_filter') == 'ne' ? ' selected="selected"' : '') . '>' . __('Not equal to', 'course-catalog-system') . '</option>';
                $output .= '<option value="lt"' . (get_post_value('program_duration_filter') == 'lt' ? ' selected="selected"' : '') . '>' . __('Less than', 'course-catalog-system') . '</option>';
                $output .= '<option value="le"' . (get_post_value('program_duration_filter') == 'le' ? ' selected="selected"' : '') . '>' . __('Less than or equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="gt"' . (get_post_value('program_duration_filter') == 'gt' ? ' selected="selected"' : '') . '>' . __('Greater than', 'course-catalog-system') . '</option>';
                $output .= '<option value="ge"' . (get_post_value('program_duration_filter') == 'ge' ? ' selected="selected"' : '') . '>' . __('Greater than or equals to', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-2 col-md-2">';
                $output .= '<input type="text" id="program_duration" name="program_duration" maxlength="2"' . (get_post_value('program_duration') ? ' value="' . get_post_value('program_duration') . '"' : '') . '>';
                $output .= '</div>';
                $output .= '<div class="col-xs-4 col-md-2">';
                $output .= '<select id="program_duration_type" name="program_duration_type">';
                $output .= '<option value="yr">' . __('Year', 'course-catalog-system') . '</option>';
                $output .= '<option value="sem"' . (get_post_value('program_duration_type') == 'sem' ? ' selected="selected"' : '') . '>' . __('Semester', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="hidden-sm col-md-3">&nbsp;</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'program_type')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_type">';
                $output .= '' . __('Programme Type', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="program_type_filter" name="program_type_filter" style="width: 100%;">';
                $output .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="ne"' . (get_post_value('program_type_filter') == 'ne' ? ' selected="selected"' : '') . '>' . __('Not equal to', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-2">';
                $output .= '<select id="program_type" name="program_type">';
                $output .= '<option value="">&nbsp;</option>';
                $output .= '<option value="F"' . (get_post_value('program_type') == 'F' ? ' selected="selected"' : '') . '>' . __('Full Time', 'course-catalog-system') . '</option>';
                $output .= '<option value="P"' . (get_post_value('program_type') == 'P' ? ' selected="selected"' : '') . '>' . __('Part Time', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="hidden-sm col-md-3">&nbsp;</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'study_mode')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 study_mode">';
                $output .= '' . __('Programme Option', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="study_mode_filter" name="study_mode_filter" style="width: 100%;">';
                $output .= '<option value="eq">' . __('Equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="ne"' . (get_post_value('study_mode_filter') == 'ne' ? ' selected="selected"' : '') . '>' . __('Not equal to', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-3">';
                $output .= '<select id="study_mode" name="study_mode">';
                $output .= '<option value="">&nbsp;</option>';
                $output .= '<option value="R"' . (get_post_value('study_mode') == 'R' ? ' selected="selected"' : '') . '>' . __('By Research', 'course-catalog-system') . '</option>';
                $output .= '<option value="C"' . (get_post_value('study_mode') == 'C' ? ' selected="selected"' : '') . '>' . __('By Coursework', 'course-catalog-system') . '</option>';
                $output .= '<option value="M"' . (get_post_value('study_mode') == 'M' ? ' selected="selected"' : '') . '>' . __('By Mixed Mode', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="hidden-sm col-md-3">&nbsp;</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'program_description')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_description">';
                $output .= '' . __('Description', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="program_description_filter" name="program_description_filter" style="width: 100%;">';
                $output .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                $output .= '<option value="nc"' . (get_post_value('program_description_filter') == 'nc' ? ' selected="selected"' : '') . '>' . __('Does not contain', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-6">';
                $output .= '<input type="text" id="program_description" name="program_description"' . (get_post_value('program_description') ? ' value="' . get_post_value('program_description') . '"' : '') . '>';
                $output .= '</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'program_careerprospect')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_careerprospect">';
                $output .= '' . __('Career Prospects', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="program_careerprospect_filter" name="program_careerprospect_filter" style="width: 100%;">';
                $output .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                $output .= '<option value="nc"' . (get_post_value('program_careerprospect_filter') == 'nc' ? ' selected="selected"' : '') . '>' . __('Does not contain', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-6">';
                $output .= '<input type="text" id="program_careerprospect" name="program_careerprospect"' . (get_post_value('program_careerprospect') ? ' value="' . get_post_value('program_careerprospect') . '"' : '') . '>';
                $output .= '</div>';
                $output .= '</div>';

            }
            else if ($field->name == 'program_tags')
            {

                $output .= '<div class="form-group clearfix">';
                $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1 program_tags">';
                $output .= '' . __('Tags', 'course-catalog-system') . '';
                $output .= '</div>';
                $output .= '<div class="col-xs-3 col-md-2">';
                $output .= '<select id="program_tags_filter" name="program_tags_filter" style="width: 100%;">';
                $output .= '<option value="ct">' . __('Contains', 'course-catalog-system') . '</option>';
                $output .= '<option value="eq"' . (get_post_value('program_tags_filter') == 'eq' ? ' selected="selected"' : '') . '>' . __('Equals to', 'course-catalog-system') . '</option>';
                $output .= '<option value="ne"' . (get_post_value('program_tags_filter') == 'ne' ? ' selected="selected"' : '') . '>' . __('Not equal to', 'course-catalog-system') . '</option>';
                $output .= '<option value="sw"' . (get_post_value('program_tags_filter') == 'sw' ? ' selected="selected"' : '') . '>' . __('Starts with', 'course-catalog-system') . '</option>';
                $output .= '<option value="ew"' . (get_post_value('program_tags_filter') == 'ew' ? ' selected="selected"' : '') . '>' . __('Ends with', 'course-catalog-system') . '</option>';
                $output .= '</select>';
                $output .= '</div>';
                $output .= '<div class="col-xs-6 col-md-6">';
                $output .= '<input type="text" id="program_tags" name="program_tags"' . (get_post_value('program_tags') ? ' value="' . get_post_value('program_tags') . '"' : '') . '>';
                $output .= '</div>';
                $output .= '<div class="hidden-sm col-md-3">&nbsp;</div>';
                $output .= '</div>';

            }
        }

        $output .= '<div class="form-group clearfix">';
        $output .= '<div class="col-xs-3 col-xs-offset-0 col-md-2 col-md-offset-1">';
        $output .= '&nbsp;';
        $output .= '</div>';
        $output .= '<div class="col-xs-8 col-md-8">';
        $output .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_search"]' . __('Search', 'course-catalog-system') . '[/button]');
        $output .= '<input type="hidden" name="search" value="1">';
        $output .= '</div>';
        $output .= '</div>';

        $output .= '</form>';
        $output .= '<script type="text/javascript">';
        $output .= 'jQuery(\'#btn_search\').on(\'click\', function() {';
        $output .= 'jQuery(\'#ccs_search_form\').submit();';
        $output .= '});';
        $output .= '</script>';

        // -- Search form init end

        $output = do_shortcode('[tagline_box highlightposition="top" margin_bottom="20px"]' . $output . '[/tagline_box]');

        if (isset($_POST['search']))
        {
            // Show search result

            $queries = $_POST;						// Array
            $queries['lang'] = $lang;

            $remote_url = $ccs_url . '/data/search_program_advance';
            $response = ccs_post_content_curl($remote_url, $queries);

            $json_data = $response['html'];
            $programs = json_decode($json_data);

            $count_local = 0;

            if (count($programs) > 0)
            {
                // Filters
                $remote_url = $ccs_url . '/data/search_program_filter';
                $response = ccs_post_content_curl($remote_url, $queries);

                $data = $response['html'];
                $filter_str = json_decode($data);

                $output .= '<a name="result"></a>';
                $output .= '<div class="search_criteria">';
                $output .= '<div style="line-height: 30px; background-color: #f4f4f6; padding: 5px 30px; margin: 0 0 15px;">';
                $output .= '<h3>' . __('Search Criteria:', 'course-catalog-system') . '</h3>';
                $output .= '<ul>';

                foreach ($filter_str as $row)
                {
                    $output .= '<li>' . str_replace('__OR__', __('OR'), $row->filter) . '</li>';
                }
                $output .= '</ul>';
                $output .= '</div>';
                $output .= '</div>';

                $output .= '<div class="table-1 search_result ccs" id="ccs_search_result">';
                $output .= '<table width="100%">';
                $output .= '<thead>';
                $output .= '<tr>';
                $output .= '<th style="width: 5%;">&nbsp;</th>';
                if ($queries['studylevel_id'] == '')
                {
                    $output .= '<th class="th_studylevel">' . __('Level of Study', 'course-catalog-system') . '</th>';
                }
                $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
                if ($queries['faculty_id'] == '')
                {
                    $output .= '<th class="th_faculty">' . __('Faculty', 'course-catalog-system') . '</th>';
                }
                $output .= '</tr>';
                $output .= '</thead>';
                $output .= '<tbody>';

                $cnt = 1;

                foreach ($programs as $program)
                {
                    $output .= '<tr>';
                    $output .= '<td style="text-align: center;">' . $cnt . '</td>';
                    if ($queries['studylevel_id'] == '')
                    {
                        $output .= '<td>' . $program->studylevel_name . '</td>';
                    }

                    $output .= '<td>';
                    if ($program->program_scope == 'L')
                    {
                        $output .= '<span style="color:red;">*</span>&nbsp;';
                        $count_local++;
                    }
                    if ( ! empty($program->program_code))
                    {
                        $output .= $program->program_code . ': ';
                    }

                    $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                    $output .= $program->program_name;
                    $output .= '</a>';

                    if ($program->program_is_new == '1')
                    {
                        $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                        $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                        $tag .= __('New');
                        $tag .= '</span>';
                        $tag .= '[/highlight]';

                        $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                    }

                    $output .= '</td>';

                    if ($queries['faculty_id'] == '')
                    {
                        $output .= '<td>' . $program->faculty_name . '</td>';
                    }

                    $output .= '</tr>';
                    $cnt++;
                }

                $output .= '</tbody>';
                $output .= '</table>';
                $output .= '</div>';

                if ($count_local > 0)
                {
                    $output .= '<div class="ccs-text ccs-note">';
                    $output .= '<br>';
                    $output .= __('Programme marked (', 'course-catalog-system') . '<span style="color:red;">*</span>';
                    $output .= __(') are not available for international students', 'course-catalog-system');
                    $output .= '</div>';
                }
            }
            else
            {
                $output .= __('No result', 'course-catalog-system');
            }

            $output .= '<div class="new_search">';
            $output .= '<br>';
            $output .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_new_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('New Search') . '[/button]');
            $output .= '</div>';

            $output .= '<script type="text/javascript">';
            $output .= "var p = jQuery('.search_criteria').siblings('p');";
            $output .= 'jQuery(p).each(function(index) { if (jQuery(this).text() == "") jQuery(p).remove()});';
            $output .= '</script>';
        }

        return $output . eol();
    }
    else
    {
        return ccs_search_box_process_new();
    }
}
add_shortcode('ccs_render_search_program', 'ccs_render_search_program');

function ccs_render_sidebar_search_program()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_details_page = $options['ccs_program_details_page'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_program_search_page = $options['ccs_program_search_page'];
    $ccs_program_search_result_page = $options['ccs_program_search_result_page'];

    if (empty($ccs_program_search_result_page))
    {
        if ( ! empty($ccs_program_search_page))
        {
            $ccs_program_search_result_page = $ccs_program_search_page;
        }
    }

    $ccs_tag_new_background_color = $options['ccs_tag_new_background_color'];
    if (empty($ccs_tag_new_background_color)) $ccs_tag_new_background_color = CCS_TAG_NEW_BGCOLOR;
    $ccs_tag_new_color = $options['ccs_tag_new_color'];
    if (empty($ccs_tag_new_color)) $ccs_tag_new_color = CCS_TAG_NEW_COLOR;

    $output = '';

    // Get faculty list
    $remote_url = $ccs_url . '/api/wordpress/faculties/' . $lang;
    $response = ccs_get_content_curl($remote_url);

    $json_data = $response['html'];
    $faculties = json_decode($json_data);

    $faculty_list = '';
    foreach ($faculties as $faculty)
    {
        if ( ! get_post_value('faculty_id'))
        {
            $faculty_list .= '<option value="' . $faculty->faculty_id .  '">' . $faculty->faculty_name . '</option>';
        }
        else
        {
            $faculty_list .= '<option value="' . $faculty->faculty_id .  '"' . (get_post_value('faculty_id') == $faculty->faculty_id ? ' selected="selected"' : '') . '>' . $faculty->faculty_name . '</option>';
        }
    }

    // Get studylevel list
    $remote_url = $ccs_url . '/api/wordpress/studylevels/' . $lang;
    $response = ccs_get_content_curl($remote_url);

    $json_data = $response['html'];
    $studylevels = json_decode($json_data);

    $studylevel_list = '';
    foreach ($studylevels as $studylevel)
    {
        if ( ! get_post_value('studylevel_id'))
        {
            $studylevel_list .= '<option value="' . $studylevel->studylevel_id .  '">' . $studylevel->studylevel_name . '</option>';
        }
        else
        {
            $studylevel_list .= '<option value="' . $studylevel->studylevel_id .  '"' . (get_post_value('studylevel_id') == $studylevel->studylevel_id ? ' selected="selected"' : '') . '>' . $studylevel->studylevel_name . '</option>';
        }
    }

    $remote_url = $ccs_url . '/api/wordpress/search_config/sidebar';
    $response = ccs_get_content_curl($remote_url);

    $json_data = $response['html'];
    $search_fields = json_decode($json_data);

    // -- Search form init start

    $output  = '<form method="post" id="ccs_search_form" name="ccs_search_form" class="ccs-form" action="#result" autocomplete="off">';

    foreach ($search_fields as $field)
    {
        if ($field->name == 'program_code')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<input type="text" id="program_code" name="program_code"' . (get_post_value('program_code') ? ' value="' . get_post_value('program_code') . '"' : '') . ' placeholder="' . __('Programme Code', 'course-catalog-system') . '">';
            $output .= '<input type="hidden" id="program_code_filter" name="program_code_filter" value="ct">';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'program_name')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<input type="text" id="program_name" name="program_name"' . (get_post_value('program_name') ? ' value="' . get_post_value('program_name') . '"' : '') . ' placeholder=" ' . __('Programme Name', 'course-catalog-system') . '">';
            $output .= '<input type="hidden" id="program_name_filter" name="program_name_filter" value="ct">';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'faculty_id')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<select id="faculty_id" name="faculty_id" placeholder="' . __('Faculty', 'course-catalog-system') . '">';
            $output .= '<option value="">&nbsp;</option>';
            $output .= $faculty_list;
            $output .= '</select>';
            $output .= '<input type="hidden" id="faculty_id_filter" name="faculty_id_filter" value="eq">';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'studylevel_id')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<select id="studylevel_id" name="studylevel_id" placeholder="' . __('Level of Study', 'course-catalog-system') . '">';
            $output .= '<option value="">&nbsp;</option>';
            $output .= $studylevel_list;
            $output .= '</select>';
            $output .= '<input type="hidden" id="studylevel_id_filter" name="studylevel_id_filter" value="eq">';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'program_credithour')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<input type="text" id="program_credithour" name="program_credithour" maxlength="2"' . (get_post_value('program_credithour') ? ' value="' . get_post_value('program_credithour') . '"' : '') . ' placeholder="' . __('Credit Hours', 'course-catalog-system') . '">';
            $output .= '<input type="hidden" id="program_credithour_filter" name="program_credithour_filter" value="eq">';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'program_duration')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<input type="text" id="program_duration" name="program_duration" maxlength="2"' . (get_post_value('program_duration') ? ' value="' . get_post_value('program_duration') . '"' : '') . ' placeholder="' . __('Programme Length', 'course-catalog-system') . '">';
            $output .= '<input type="hidden" id="program_duration_filter" name="program_duration_filter" value="eq">';
            $output .= '</div>';
            $output .= '</div>';

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<select id="program_duration_type" name="program_duration_type">';
            $output .= '<option value="yr">' . __('Year', 'course-catalog-system') . '</option>';
            $output .= '<option value="sem"' . (get_post_value('program_duration_type') == 'sem' ? ' selected="selected"' : '') . '>' . __('Semester', 'course-catalog-system') . '</option>';
            $output .= '</select>';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'program_type')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<select id="program_type" name="program_type" placeholder="' . __('Programme Type', 'course-catalog-system') . '">';
            $output .= '<option value="">&nbsp;</option>';
            $output .= '<option value="F"' . (get_post_value('program_type') == 'F' ? ' selected="selected"' : '') . '>' . __('Full Time', 'course-catalog-system') . '</option>';
            $output .= '<option value="P"' . (get_post_value('program_type') == 'P' ? ' selected="selected"' : '') . '>' . __('Part Time', 'course-catalog-system') . '</option>';
            $output .= '</select>';
            $output .= '<input type="hidden" id="program_type_filter" name="program_type_filter" value="eq">';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'study_mode')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<select id="study_mode" name="study_mode" placeholder="' . __('Programme Option', 'course-catalog-system') . '">';
            $output .= '<option value="">&nbsp;</option>';
            $output .= '<option value="R"' . (get_post_value('study_mode') == 'R' ? ' selected="selected"' : '') . '>' . __('By Research', 'course-catalog-system') . '</option>';
            $output .= '<option value="C"' . (get_post_value('study_mode') == 'C' ? ' selected="selected"' : '') . '>' . __('By Coursework', 'course-catalog-system') . '</option>';
            $output .= '<option value="M"' . (get_post_value('study_mode') == 'M' ? ' selected="selected"' : '') . '>' . __('By Mixed Mode', 'course-catalog-system') . '</option>';
            $output .= '</select>';
            $output .= '<input type="hidden" id="study_mode_filter" name="study_mode_filter" value="eq">';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'program_description')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<input type="text" id="program_description" name="program_description"' . (get_post_value('program_description') ? ' value="' . get_post_value('program_description') . '"' : '') . ' placeholder="' . __('Description', 'course-catalog-system') . '">';
            $output .= '<input type="hidden" id="program_description_filter" name="program_description_filter" value="ct">';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'program_careerprospect')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<input type="text" id="program_careerprospect" name="program_careerprospect"' . (get_post_value('program_careerprospect') ? ' value="' . get_post_value('program_careerprospect') . '"' : '') . ' placeholder="' . __('Career Prospects', 'course-catalog-system') . '">';
            $output .= '<input type="hidden" id="program_careerprospect_filter" name="program_careerprospect_filter" value="ct">';
            $output .= '</div>';
            $output .= '</div>';

        }
        else if ($field->name == 'program_tags')
        {

            $output .= '<div class="form-group clearfix">';
            $output .= '<div class="col-xs-12">';
            $output .= '<input type="text" id="program_tags" name="program_tags"' . (get_post_value('program_tags') ? ' value="' . get_post_value('program_tags') . '"' : '') . ' placeholder="' . __('Tags', 'course-catalog-system') . '">';
            $output .= '<input type="hidden" id="program_tags_filter" name="program_tags_filter" value="ct">';
            $output .= '</div>';
            $output .= '</div>';

        }
    }

    $output .= '<br>';
    $output .= '<div class="form-group clearfix">';
    $output .= '<div class="col-xs-8 col-xs-offset-2">';
    $output .= do_shortcode('[button type="default" shape="default" icon="fa-search" stretch="yes" id="btn_search"]' . __('Search', 'course-catalog-system') . '[/button]');
    $output .= '<input type="hidden" name="search" value="1">';
    $output .= '</div>';
    $output .= '</div>';

    $output .= '</form>';

//    $output .= '<script type="text/javascript">';
//    $output .= 'jQuery(\'#btn_search\').on(\'click\', function() {';
//    $output .= 'jQuery(\'#ccs_search_form\').submit();';
//    $output .= '});';
//    $output .= '</script>';

    // -- Search form init end

    $output = do_shortcode('[tagline_box highlightposition="top" margin_bottom="20px"]' . $output . '[/tagline_box]') .
                '<div class="search_result"></div>';

    // Append JS here

    $sidebar_search = file_get_contents(CCS_SIDEBAR_SEARCH);

    if ($sidebar_search !== FALSE)
    {
        $sidebar_search = str_replace('<!--{{CCS_URL}}-->', $ccs_url, $sidebar_search);
        $sidebar_search = str_replace('<!--{{LANG}}-->', $lang, $sidebar_search);
        $sidebar_search = str_replace('<!--{{SITE_URL}}-->', get_site_url(), $sidebar_search);
        $sidebar_search = str_replace('<!--{{PROGRAM_DETAILS_PAGE}}-->', $lang, $sidebar_search);
        $sidebar_search = str_replace('<!--{{PROGRAM_ID_PARAM}}-->', $lang, $sidebar_search);

        $sidebar_search = str_replace('<!--{{LEVEL_OF_STUDY}}-->', __('Level of Study', 'course-catalog-system'), $sidebar_search);
        $sidebar_search = str_replace('<!--{{SEARCH_RESULT}}-->', __('Search Result', 'course-catalog-system'), $sidebar_search);
        $sidebar_search = str_replace('<!--{{CONTAINS}}-->', __('contains', 'course-catalog-system'), $sidebar_search);
        $sidebar_search = str_replace('<!--{{EQUALS}}-->', __('equals to', 'course-catalog-system'), $sidebar_search);
        $sidebar_search = str_replace('<!--{{SEARCH_CRITERIA}}-->', __('Search Criteria', 'course-catalog-system'), $sidebar_search);

        $output .= $sidebar_search;
    }


    // The following section shall be converted to JS

    if (isset($_POST['search']))
    {
        // Show search result

        $queries = $_POST;						// Array
        $queries['lang'] = $lang;

        $remote_url = $ccs_url . '/data/search_program_advance';
        $response = ccs_post_content_curl($remote_url, $queries);

        $json_data = $response['html'];
        $programs = json_decode($json_data);

        $count_local = 0;

        if (count($programs) > 0)
        {
            // Filters
            $remote_url = $ccs_url . '/data/search_program_filter';
            $response = ccs_post_content_curl($remote_url, $queries);

            $data = $response['html'];
            $filter_str = json_decode($data);

            $output .= '<a name="result"></a>';
            $output .= '<div class="search_criteria">';
            $output .= '<div style="line-height: 30px; background-color: #f4f4f6; padding: 5px 30px; margin: 0 0 15px;">';
            $output .= '<h3>' . __('Search Criteria:', 'course-catalog-system') . '</h3>';
            $output .= '<ul>';

            foreach ($filter_str as $row)
            {
                $output .= '<li>' . str_replace('__OR__', __('OR'), $row->filter) . '</li>';
            }
            $output .= '</ul>';
            $output .= '</div>';
            $output .= '</div>';

            $output .= '<div class="table-1 search_result ccs" id="ccs_search_result">';
            $output .= '<table width="100%">';
            $output .= '<thead>';
            $output .= '<tr>';
            $output .= '<th style="width: 5%;">&nbsp;</th>';
            if ($queries['studylevel_id'] == '')
            {
                $output .= '<th class="th_studylevel">' . __('Level of Study', 'course-catalog-system') . '</th>';
            }
            $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
            if ($queries['faculty_id'] == '')
            {
                $output .= '<th class="th_faculty">' . __('Faculty', 'course-catalog-system') . '</th>';
            }
            $output .= '</tr>';
            $output .= '</thead>';
            $output .= '<tbody>';

            $cnt = 1;

            foreach ($programs as $program)
            {
                $output .= '<tr>';
                $output .= '<td style="text-align: center;">' . $cnt . '</td>';
                if ($queries['studylevel_id'] == '')
                {
                    $output .= '<td>' . $program->studylevel_name . '</td>';
                }

                $output .= '<td>';
                if ($program->program_scope == 'L')
                {
                    $output .= '<span style="color:red;">*</span>&nbsp;';
                    $count_local++;
                }
                if ( ! empty($program->program_code))
                {
                    $output .= $program->program_code . ': ';
                }

                $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                $output .= $program->program_name;
                $output .= '</a>';

                if ($program->program_is_new == '1')
                {
                    $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                    $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                    $tag .= __('New');
                    $tag .= '</span>';
                    $tag .= '[/highlight]';

                    $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                }

                $output .= '</td>';

                if ($queries['faculty_id'] == '')
                {
                    $output .= '<td>' . $program->faculty_name . '</td>';
                }

                $output .= '</tr>';
                $cnt++;
            }

            $output .= '</tbody>';
            $output .= '</table>';
            $output .= '</div>';

            if ($count_local > 0)
            {
                $output .= '<div class="ccs-text ccs-note">';
                $output .= '<br>';
                $output .= __('Programme marked (', 'course-catalog-system') . '<span style="color:red;">*</span>';
                $output .= __(') are not available for international students', 'course-catalog-system');
                $output .= '</div>';
            }
        }
        else
        {
            $output .= __('No result', 'course-catalog-system');
        }

        $output .= '<div class="new_search">';
        $output .= '<br>';
        $output .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_new_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('New Search') . '[/button]');
        $output .= '</div>';

        $output .= '<script type="text/javascript">';
        $output .= "var p = jQuery('.search_criteria').siblings('p');";
        $output .= 'jQuery(p).each(function(index) { if (jQuery(this).text() == "") jQuery(p).remove()});';
        $output .= '</script>';
    }

    return $output . eol();
}
add_shortcode('ccs_render_sidebar_search_program', 'ccs_render_sidebar_search_program');

function get_post_value($name)
{
    if (isset($_POST[$name]))
    {
        if ($_POST[$name] != '')
        {
            return $_POST[$name];
        }
    }

    return false;
}

function ccs_render_search_result()
{
    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_details_page = $options['ccs_program_details_page'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $ccs_program_search_page = $options['ccs_program_search_page'];
    $ccs_program_search_result_page = $options['ccs_program_search_result_page'];

    if (empty($ccs_program_search_result_page))
    {
        if ( ! empty($ccs_program_search_page))
        {
            $ccs_program_search_result_page = $ccs_program_search_page;
        }
    }

    $ccs_tag_new_background_color = $options['ccs_tag_new_background_color'];
    if (empty($ccs_tag_new_background_color)) $ccs_tag_new_background_color = CCS_TAG_NEW_BGCOLOR;
    $ccs_tag_new_color = $options['ccs_tag_new_color'];
    if (empty($ccs_tag_new_color)) $ccs_tag_new_color = CCS_TAG_NEW_COLOR;

    if (isset($_POST['search']))
    {
        // Show search result

        $queries = $_POST;						// Array
        $queries['lang'] = $lang;

        $remote_url = $ccs_url . '/data/search_program_advance';
        $response = ccs_post_content_curl($remote_url, $queries);

        $json_data = $response['html'];
        $programs = json_decode($json_data);

        $output = '';
        $count_local = 0;

        if (count($programs) > 0)
        {
            // Filters
            $remote_url = $ccs_url . '/data/search_program_filter';
            $response = ccs_post_content_curl($remote_url, $queries);

            $data = $response['html'];
            $filter_str = json_decode($data);

            $output .= '<div class="search_criteria">';
            $output .= '<div style="line-height: 30px; background-color: #f4f4f6; padding: 5px 30px; margin: 0 0 15px;">';
            $output .= '<h3>' . __('Search Criteria:', 'course-catalog-system') . '</h3>';
            $output .= '<ul>';

            foreach ($filter_str as $row)
            {
                $output .= '<li>' . str_replace('__OR__', __('OR'), $row->filter) . '</li>';
            }
            $output .= '</ul>';
            $output .= '</div>';
            $output .= '</div>';

            $output .= '<div class="table-1 search_result ccs" id="ccs_search_result">';
            $output .= '<table width="100%">';
            $output .= '<thead>';
            $output .= '<tr>';
            $output .= '<th style="width: 5%;">&nbsp;</th>';
            if ($queries['studylevel_id'] == '')
            {
                $output .= '<th class="th_studylevel">' . __('Level of Study', 'course-catalog-system') . '</th>';
            }
            $output .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
            if ($queries['faculty_id'] == '')
            {
                $output .= '<th class="th_faculty">' . __('Faculty', 'course-catalog-system') . '</th>';
            }
            $output .= '</tr>';
            $output .= '</thead>';
            $output .= '<tbody>';

            $cnt = 1;

            foreach ($programs as $program)
            {
                $output .= '<tr>';
                $output .= '<td style="text-align: center;">' . $cnt . '</td>';
                if ($queries['studylevel_id'] == '')
                {
                    $output .= '<td>' . $program->studylevel_name . '</td>';
                }

                $output .= '<td>';
                if ($program->program_scope == 'L')
                {
                    $output .= '<span style="color:red;">*</span>&nbsp;';
                    $count_local++;
                }
                if ( ! empty($program->program_code))
                {
                    $output .= $program->program_code . ': ';
                }

                $output .= '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">';
                $output .= $program->program_name;
                $output .= '</a>';

                if ($program->program_is_new == '1')
                {
                    $tag  = '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                    $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                    $tag .= __('New');
                    $tag .= '</span>';
                    $tag .= '[/highlight]';

                    $output .= '&nbsp;&nbsp;' . do_shortcode($tag);
                }

                $output .= '</td>';

                if ($queries['faculty_id'] == '')
                {
                    $output .= '<td>' . $program->faculty_name . '</td>';
                }

                $output .= '</tr>';
                $cnt++;
            }

            $output .= '</tbody>';
            $output .= '</table>';
            $output .= '</div>';

            if ($count_local > 0)
            {
                $output .= '<div class="ccs-text ccs-note">';
                $output .= '<br>';
                $output .= __('Programme marked (', 'course-catalog-system') . '<span style="color:red;">*</span>';
                $output .= __(') are not available for international students', 'course-catalog-system');
                $output .= '</div>';
            }
        }
        else
        {
            $output .= __('No result', 'course-catalog-system');
        }

        $output .= '<div class="new_search">';
        $output .= '<br>';
        $output .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_new_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('New Search') . '[/button]');
        $output .= '</div>';

        $output .= '<script type="text/javascript">';
        $output .= "var p = jQuery('.search_criteria').siblings('p');";
        $output .= 'jQuery(p).each(function(index) { if (jQuery(this).text() == "") jQuery(p).remove()});';
        $output .= '</script>';

        return $output . eol();
    }
}
add_shortcode('ccs_render_search_result', 'ccs_render_search_result');

function get_filter_string($filter)
{
    switch ($filter)
    {
        case 'eq':
            return __('Equals to', 'course-catalog-system');
            break;
        case 'ne':
            return __('Not equal to', 'course-catalog-system');
            break;
        case 'le':
            return __('Less than or equals to', 'course-catalog-system');
            break;
        case 'lt':
            return __('Less than', 'course-catalog-system');
            break;
        case 'ge':
            return __('Greater than or equals to', 'course-catalog-system');
            break;
        case 'gt':
            return __('Greater than', 'course-catalog-system');
            break;
        case 'ct':
            return __('Contains', 'course-catalog-system');
            break;
        case 'sw':
            return __('Starts with', 'course-catalog-system');
            break;
        case 'ew':
            return __('Ends with', 'course-catalog-system');
            break;
        default:
            return '';
            break;
    }
}

function ccs_render_search_box($atts)
{
    $attributes = shortcode_atts(array(
        'border' => 'none'			// Default to Undergraduate Studies
    ), $atts);

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_program_search_page = $options['ccs_program_search_page'];

    $search_box = file_get_contents(CCS_SEARCH_BOX);

    if ($search_box !== FALSE)
    {
        $search_box = str_replace('<!--{{SEARCH_PAGE}}-->', get_site_url() . $ccs_program_search_page, $search_box);
        $search_box = str_replace('<!--{{SEARCH_LABEL}}-->', __('Find a Course', 'course-catalog-system'), $search_box);
        $search_box = str_replace('<!--{{SEARCH_BUTTON}}-->', __('Search', 'course-catalog-system'), $search_box);

        $border = 'none';
        if (in_array($attributes['border'], array('top', 'bottom', 'left', 'right')))
        {
            $border = $attributes['border'];
        }

        $search_box = do_shortcode('[tagline_box highlightposition="' . $border . '" margin_top="0px" margin_bottom="0px"]' . $search_box . '[/tagline_box]');

        // WARNING: Using the following code (eval) will make the output appear at the top of the page!!!
        //$search_box = eval("? >$search_box");

        return $search_box . eol();
    }

    return '';
}
add_shortcode('ccs_render_search_box', 'ccs_render_search_box');

/**
 * Show search from simple search
 */
function ccs_search_box_process_new()
{
    if (isset($_GET['query']))
    {
        if (defined('ICL_LANGUAGE_CODE'))
        {
            $lang = ICL_LANGUAGE_CODE;
        }
        else
        {
            if (function_exists('qtranxf_getLanguage'))
            {
                $lang = qtranxf_getLanguage();
            }
            else
            {
                $lang = 'en';
            }
        }

        // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
        // Each __() function must be __('Words to translate', 'course-catalog-system')
        load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

        $options = get_option(CCS_OPTION_NAME);
        $ccs_url = $options['ccs_url'];
        $ccs_program_details_page = $options['ccs_program_details_page'];
        $ccs_program_id_param = $options['ccs_program_id_param'];
        $ccs_program_search_page = $options['ccs_program_search_page'];
        $ccs_tag_new_background_color = $options['ccs_tag_new_background_color'];
        if (empty($ccs_tag_new_background_color)) $ccs_tag_new_background_color = CCS_TAG_NEW_BGCOLOR;
        $ccs_tag_new_color = $options['ccs_tag_new_color'];
        if (empty($ccs_tag_new_color)) $ccs_tag_new_color = CCS_TAG_NEW_COLOR;

        $query = $_GET['query'];
        $query = str_replace(' ', '%2B', $query);

        $remote_url = $ccs_url . '/api/wordpress/search_program/' . $query . '/' . $lang;
        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $programs = json_decode($json_data);

        $output = '';
        $result = '';

        if (count($programs) > 0)
        {
            $search_result_top  = '<div class="new_search">';
            $search_result_top .= '<div class="search_criteria" style="line-height: 30px; background-color: #f4f4f6; padding: 5px 30px; margin: 15px 0;">';
            $search_result_top .= '<h3>' . __('Search Criteria:', 'course-catalog-system') . '</h3>';

            $query = $_GET['query'];
            $queries = explode(' ' , $query);
            $query_filters = '';

            for ($a = 0; $a < count($queries); $a++)
            {
                if ($a == 0)
                {
                    $query_filters = '&#39;' . $queries[$a] . '&#39;';
                }
                else
                {
                    $query_filters .= ' ' . __('OR') . ' &#39;' . $queries[$a] . '&#39;';
                }
            }
            $search_result_top .= '<ul>';
            $search_result_top .= '<li>' . __('Tags contains') . ' ' . $query_filters . '</li>';
            $search_result_top .= '</ul>';

            $search_result_top .= '</div>';
            $search_result_top .= '</div>';
            $search_result_top .= '<div class="table-1 search_result ccs" id="ccs_search_result">';
            $search_result_top .= '<table width="100%">';
            $search_result_top .= '<thead>';
            $search_result_top .= '<tr>';
            $search_result_top .= '<th style="width: 5%;">&nbsp;</th>';
            $search_result_top .= '<th class="th_faculty">' . __('Faculty', 'course-catalog-system') . '</th>';
            $search_result_top .= '<th class="th_studylevel">' . __('Level of Study', 'course-catalog-system') . '</th>';
            $search_result_top .= '<th>' . __('Programme', 'course-catalog-system') . '</th>';
            $search_result_top .= '</tr>';
            $search_result_top .= '</thead>';
            $search_result_top .= '<tbody>';

            $cnt = 0;
            $local = 0;

            foreach ($programs as $program)
            {
                $cnt++;

                $tag = '';
                if ($program->program_is_new == '1')
                {
                    $tag .= '[highlight color="' . $ccs_tag_new_background_color . '" rounded="yes"]';
                    $tag .= '<span style="color: ' . $ccs_tag_new_color . ';">';
                    $tag .= __('New');
                    $tag .= '</span>';
                    $tag .= '[/highlight]';

                    $tag = '&nbsp;&nbsp;' . do_shortcode($tag);
                }

                $result .= 	'<tr>' .
                                '<td style="text-align: center;">' . $cnt . '</td>' .
                                '<td>' . $program->faculty_name . '</td>' .
                                '<td>' . $program->studylevel_name . '</td>' .
                                '<td>' .
                                '<a href="' . get_site_url() . $ccs_program_details_page . '?' . $ccs_program_id_param . '=' . $program->program_id . '">' .
                                ($program->program_scope == 'L' ? '<span style="color:red;">*</span>&nbsp;' : '')  .
                                (($program->program_code != '' && $program->program_code != null) ? $program->program_code . ': ' : '') .
                                $program->program_name . '</a>' .
                                $tag .
                                '</td>' .
                            '</tr>';
                if ($program->program_scope == 'L')
                {
                    $local++;
                }
            }

            $search_result_bottom  = '</tbody>';
            $search_result_bottom .= '</table>';
            $search_result_bottom .= '</div>';

            if ($local > 0)
            {
                $search_result_bottom .= '<div class="ccs-text ccs-note">';
                $search_result_bottom .= '<br>';
                $search_result_bottom .= __('Programme marked (', 'course-catalog-system') . '<span style="color:red;">*</span>';
                $search_result_bottom .= __(') are not available for international students', 'course-catalog-system');
                $search_result_bottom .= '</div>';
            }

            $search_result_bottom .= '<div class="new_search">';
            $search_result_bottom .= '<br>';
            $search_result_bottom .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_new_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('New Search') . '[/button]');
            $search_result_bottom .= '</div>';

            $output .= $search_result_top . $result . $search_result_bottom;

            return $output . eol();
        }
        else
        {
            $search_no_result  = __('No result', 'course-catalog-system');

            $search_no_result .= '<div class="new_search">';
            $search_no_result .= '<br>';
            $search_no_result .= do_shortcode('[button type="default" shape="default" icon="fa-search" id="btn_new_search" link="' . get_site_url() . $ccs_program_search_page . '"]' . __('New Search') . '[/button]');
            $search_no_result .= '</div>';

            return $search_no_result . eol();
        }
    }
    else
    {
        return '';
    }
}

function ccs_search_box_process()
{
    return '';
}
add_shortcode('ccs_search_box_process', 'ccs_search_box_process');

/**
 * List programme contents by content id, the position is set on Wordpress page
 */
function ccs_render_program_content($atts)
{
    // /api/wordpress/htmlcontent/{program_id}/{content_id}

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    // Tells Wordpress to load language file from /wp-content/languages/plugins/ folder (course-catalog-system-{locale}.po)
    // Each __() function must be __('Words to translate', 'course-catalog-system')
    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $attributes = shortcode_atts(array(
        'content_id' => '',
        'width' => '400',
        'height' => '300',
        'align' => 'left',
        'autoplay' => 'no',
        'box' => 'false'
    ), $atts);

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    $ccs_faculty_id_param = $options['ccs_faculty_id_param'];
    $ccs_program_id_param = $options['ccs_program_id_param'];
    $text_align = (isset($attributes['align']) ? $attributes['align'] : '');

    $pid = isset( $_GET[$ccs_program_id_param] ) ? $_GET[$ccs_program_id_param] : '';

    $output = '';

    if ( ! empty($pid) && ! empty($attributes['content_id']))
    {
        $remote_url = $options['ccs_url'] . '/api/wordpress/htmlcontent/' . $pid . '/' . $attributes['content_id'] . '/' . $lang;

        $response = ccs_get_content_curl($remote_url);

        $json_data = $response['html'];
        $program_contents = json_decode($json_data);

        foreach ($program_contents as $program_content)
        {
            if ( ! empty($program_content->content_description))
            {
                if ($program_content->content_type == 'I')
                {
                    if (empty($text_align))
                    {
                        $output .= '<img src="' . $program_content->content_description . '" alt="">';
                    }
                    else
                    {
                        $output .= '<div style="text-align:' . $text_align . ';">' . '<img src="' . $program_content->content_description . '" alt="">' . '</div>';
                    }
                }
                else if ($program_content->content_type == 'V')
                {
                    if (stripos($program_content->content_description, 'youtube.com/') !== false)
                    {
                        $video_id = '';
                        if (stripos($program_content->content_description, '/embed/') !== false)
                        {
                            $video_id = substr($program_content->content_description, stripos($program_content->content_description, '/embed/') + strlen('/embed/'));
                        }
                        else if (stripos($program_content->content_description, '?v=') !== false)
                        {
                            $video_id = substr($program_content->content_description, stripos($program_content->content_description, '?v=') + strlen('?v='));
                        }
                        else if (stripos($program_content->content_description, '&v=') !== false)
                        {
                            $video_id = substr($program_content->content_description, stripos($program_content->content_description, '&v=') + strlen('&v='));
                        }

                        if (stripos($video_id, '&') !== false)
                        {
                            $video_id = substr($video_id, 0, stripos($video_id, '&'));
                        }

                        if ( ! empty($video_id))
                        {
                            if (empty($text_align))
                            {
                                $output .= do_shortcode('[youtube id="' . $video_id . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" autoplay="' . $attributes['autoplay'] . '"]');
                            }
                            else
                            {
                                $output .= '<div style="text-align:' . $text_align . ';">' . do_shortcode('[youtube id="' . $video_id . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" autoplay="' . $attributes['autoplay'] . '"]') . '</div>';
                            }
                        }
                    }
                    else if (stripos($program_content->content_description, 'vimeo.com/') !== false)
                    {
                        $video_id = '';
                        if (stripos($program_content->content_description, 'vimeo.com/') !== false)
                        {
                            $video_id = substr($program_content->content_description, stripos($program_content->content_description, 'vimeo.com/') + strlen('vimeo.com/'));
                        }

                        if (stripos($video_id, '&') !== false)
                        {
                            $video_id = substr($video_id, 0, stripos($video_id, '&'));
                        }

                        if (stripos($video_id, '?') !== false)
                        {
                            $video_id = substr($video_id, 0, stripos($video_id, '?'));
                        }

                        if ( ! empty($video_id))
                        {
                            if (empty($text_align))
                            {
                                $output .= do_shortcode('[vimeo id="' . $video_id . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" autoplay="' . $attributes['autoplay'] . '"]');
                            }
                            else
                            {
                                $output .= '<div style="text-align:' . $text_align . ';">' . do_shortcode('[vimeo id="' . $video_id . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" autoplay="' . $attributes['autoplay'] . '"]') . '</div>';
                            }
                        }
                    }
                    else
                    {
                        if (empty($text_align))
                        {
                            $output .= '<iframe src="' . $program_content->content_description . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" type="text/html" frameborder="0"></iframe>';
                        }
                        else
                        {
                            $output .= '<div style="text-align:' . $text_align . ';">' . '<iframe src="' . $program_content->content_description . '" width="' . $attributes['width'] . '" height="' . $attributes['height'] . '" type="text/html" frameborder="0"></iframe>' . '</div>';
                        }
                    }
                }
                else
                {
                    $content = htmlspecialchars_decode($program_content->content_description);
                    if (empty($text_align))
                    {
                        $output .= '<div>' . do_shortcode($content) . '</div>';
                    }
                    else
                    {
                        $output .= '<div style="text-align:' . $text_align . ';">' . do_shortcode($content) . '</div>';
                    }
                }
            }
        }
    }

    if ( ! empty($output))
    {
        if ($attributes['box'] == 'true')
        {
            return do_shortcode('[tagline_box highlightposition="top" margin_bottom="20px"]' . $output . '[/tagline_box]');
        }
    }

    return $output . eol();
}
add_shortcode('ccs_render_program_content', 'ccs_render_program_content');

function ccs_test($atts = null)
{
    $out = date("Y/m/d h:i:s a") . '<br>';

    if (defined('ICL_LANGUAGE_CODE'))
    {
        $lang = ICL_LANGUAGE_CODE;
    }
    else
    {
        if (function_exists('qtranxf_getLanguage'))
        {
            $lang = qtranxf_getLanguage();
        }
        else
        {
            $lang = 'en';
        }
    }

    if ( ! empty($atts))
    {
        $attributes = shortcode_atts(array(
            'path' => ''
        ), $atts);
    }

    $path = '';

    if ( ! empty($attributes['path']))
    {
        $path = $attributes['path'];
    }
    else
    {
        $path = '/api/wordpress/faculties/' . $lang;
    }

    load_plugin_textdomain('course-catalog-system', false, dirname(plugin_basename(__FILE__)) . '/language/');

    $out .= 'Option file: ' . CCS_PLUGIN_PATH . 'ccs-options.php' . '<br><br>';

    $options = get_option(CCS_OPTION_NAME);
    $ccs_url = $options['ccs_url'];
    if ( ! empty($ccs_url))
    {
        $remote_url = $options['ccs_url'] . $path;
    }
    else
    {
        $remote_url = 'http://pcs.usim.edu.my' . $path;
    }

    $out .= 'Options: ' . print_r($options, true) . '<br>';

    $out .= 'Remote URL: ' . $remote_url . '<br>';

    if (empty($ccs_url))
    {
        $out .= 'ERROR: Cannot read CCS configuration<br>';
    }

    if ( ! function_exists('file_get_contents'))
    {
        $out .= 'Function file_get_contents is disabled<br>';
    }

    if ( ! is_callable('curl_init'))
    {
        $out .= 'Function cURL is disabled<br>';
    }

    $response = ccs_get_content_curl($remote_url);

    $out .= 'Response - HTTP Code: ' . $response['http_code'] . '<br>';
    $out .= 'Method : ' . $response['method'] . '<br>';
    $out .= 'HTML : ' . $response['html'] . '<br><br>';
    $out .= 'Ping pcs.usim.edu.my : ' . ping('pcs.usim.edu.my', 80, 10) . '<br><br>';
//    $out .= 'Traceroute pcs.usim.edu.my : ' . traceroute('pcs.usim.edu.my');
    $out .= date("Y/m/d h:i:s a");

    return $out;
}
add_shortcode('ccs_test', 'ccs_test');

function ccs_options($atts = null)
{
    $options = get_option(CCS_OPTION_NAME);
    return print_r($options, true);
}
add_shortcode('ccs_options', 'ccs_options');

//Echoing it will display the ping if the host is up, if not it'll say "down".
//echo ping("www.google.com", 80, 10);
function ping($host, $port, $timeout)
{
    $tB = microtime(true);
    $fP = @fsockopen($host, $port, $errno, $errstr, $timeout);
    if (!$fP) { return "Server " . $host . " is down or connection timeout"; }
    $tA = microtime(true);
    return round((($tA - $tB) * 1000), 0)." ms";
}

function traceroute($host)
{
    exec('traceroute -n ' . $host . ' 2>&1', $out, $code);
    if ($code) {
        exec('tracert ' . $host . '', $out, $code);
        if ($code) {
            return "An error occurred while trying to traceroute/tracert: " . join("<br>", $out);
        }
    }
    return join("<br>", $out);
}

function ccs_info()
{
    $out  = 'Option file: ' . CCS_PLUGIN_PATH . 'ccs-options.php' . '<br>';

    $options = get_option(CCS_OPTION_NAME);
    $options_str = implode('---', $options);

    $out = $options_str;

    return $out;
}
add_shortcode('ccs_info', 'ccs_info');

























































function eol() { return '<!-- Programme Catalog System plugin by Nizma Resources (http://www.nizma.com.my) -->'; }
